Class: Aws::BedrockAgentCore::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::BedrockAgentCore::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-bedrockagentcore/client.rb,
sig/client.rbs
Overview
An API client for BedrockAgentCore. To construct a client, you need to configure a :region and :credentials.
client = Aws::BedrockAgentCore::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _BatchCreateMemoryRecordsResponseSuccess, _BatchDeleteMemoryRecordsResponseSuccess, _BatchUpdateMemoryRecordsResponseSuccess, _CompleteResourceTokenAuthResponseSuccess, _CreateABTestResponseSuccess, _CreateEventResponseSuccess, _CreatePaymentInstrumentResponseSuccess, _CreatePaymentSessionResponseSuccess, _DeleteABTestResponseSuccess, _DeleteBatchEvaluationResponseSuccess, _DeleteCapacityProviderSessionResponseSuccess, _DeleteEventResponseSuccess, _DeleteMemoryRecordResponseSuccess, _DeletePaymentInstrumentResponseSuccess, _DeletePaymentSessionResponseSuccess, _DeleteRecommendationResponseSuccess, _EvaluateResponseSuccess, _GetABTestResponseSuccess, _GetAgentCardResponseSuccess, _GetBatchEvaluationResponseSuccess, _GetBrowserSessionResponseSuccess, _GetCodeInterpreterSessionResponseSuccess, _GetEventResponseSuccess, _GetMemoryRecordResponseSuccess, _GetPaymentInstrumentBalanceResponseSuccess, _GetPaymentInstrumentResponseSuccess, _GetPaymentSessionResponseSuccess, _GetRecommendationResponseSuccess, _GetResourceApiKeyResponseSuccess, _GetResourceOauth2TokenResponseSuccess, _GetResourcePaymentTokenResponseSuccess, _GetWorkloadAccessTokenForJWTResponseSuccess, _GetWorkloadAccessTokenForUserIdResponseSuccess, _GetWorkloadAccessTokenResponseSuccess, _InvokeAgentRuntimeCommandResponseSuccess, _InvokeAgentRuntimeResponseSuccess, _InvokeBrowserResponseSuccess, _InvokeCodeInterpreterResponseSuccess, _InvokeHarnessResponseSuccess, _ListABTestsResponseSuccess, _ListActorsResponseSuccess, _ListBatchEvaluationsResponseSuccess, _ListBrowserSessionsResponseSuccess, _ListCodeInterpreterSessionsResponseSuccess, _ListEventsResponseSuccess, _ListMemoryExtractionJobsResponseSuccess, _ListMemoryRecordsResponseSuccess, _ListPaymentInstrumentsResponseSuccess, _ListPaymentSessionsResponseSuccess, _ListRecommendationsResponseSuccess, _ListSessionsResponseSuccess, _ProcessPaymentResponseSuccess, _RetrieveMemoryRecordsResponseSuccess, _SaveBrowserSessionProfileResponseSuccess, _SearchRegistryRecordsResponseSuccess, _StartBatchEvaluationResponseSuccess, _StartBrowserSessionResponseSuccess, _StartCodeInterpreterSessionResponseSuccess, _StartMemoryExtractionJobResponseSuccess, _StartRecommendationResponseSuccess, _StopBatchEvaluationResponseSuccess, _StopBrowserSessionResponseSuccess, _StopCodeInterpreterSessionResponseSuccess, _StopRuntimeSessionResponseSuccess, _UpdateABTestResponseSuccess, _UpdateBrowserStreamResponseSuccess
Constant Summary collapse
- Params =
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_create_memory_records(params = {}) ⇒ Types::BatchCreateMemoryRecordsOutput
Creates multiple memory records in a single batch operation for the specified memory with custom content.
-
#batch_delete_memory_records(params = {}) ⇒ Types::BatchDeleteMemoryRecordsOutput
Deletes multiple memory records in a single batch operation from the specified memory.
-
#batch_update_memory_records(params = {}) ⇒ Types::BatchUpdateMemoryRecordsOutput
Updates multiple memory records with custom content in a single batch operation within the specified memory.
-
#complete_resource_token_auth(params = {}) ⇒ Struct
Confirms the user authentication session for obtaining OAuth2.0 tokens for a resource.
-
#create_ab_test(params = {}) ⇒ Types::CreateABTestResponse
Creates an A/B test for comparing agent configurations.
-
#create_event(params = {}) ⇒ Types::CreateEventOutput
Creates an event in an AgentCore Memory resource.
-
#create_payment_instrument(params = {}) ⇒ Types::CreatePaymentInstrumentResponse
Create a new payment instrument for a connector.
-
#create_payment_session(params = {}) ⇒ Types::CreatePaymentSessionResponse
Create a new payment session.
-
#delete_ab_test(params = {}) ⇒ Types::DeleteABTestResponse
Deletes an A/B test and its associated gateway rules.
-
#delete_batch_evaluation(params = {}) ⇒ Types::DeleteBatchEvaluationResponse
Deletes a batch evaluation and its associated results.
-
#delete_capacity_provider_session(params = {}) ⇒ Types::DeleteCapacityProviderSessionResponse
Deletes a session associated with a capacity provider in Amazon Bedrock AgentCore and makes the session unavailable for further use.
-
#delete_event(params = {}) ⇒ Types::DeleteEventOutput
Deletes an event from an AgentCore Memory resource.
-
#delete_memory_record(params = {}) ⇒ Types::DeleteMemoryRecordOutput
Deletes a memory record from an AgentCore Memory resource.
-
#delete_payment_instrument(params = {}) ⇒ Types::DeletePaymentInstrumentResponse
Deletes a payment instrument.
-
#delete_payment_session(params = {}) ⇒ Types::DeletePaymentSessionResponse
Deletes a payment session.
-
#delete_recommendation(params = {}) ⇒ Types::DeleteRecommendationResponse
Deletes a recommendation and its associated results.
-
#evaluate(params = {}) ⇒ Types::EvaluateResponse
Performs on-demand evaluation of agent traces using a specified evaluator.
-
#get_ab_test(params = {}) ⇒ Types::GetABTestResponse
Retrieves detailed information about an A/B test, including its configuration, status, and statistical results.
-
#get_agent_card(params = {}) ⇒ Types::GetAgentCardResponse
Retrieves the A2A agent card associated with an AgentCore Runtime agent.
-
#get_batch_evaluation(params = {}) ⇒ Types::GetBatchEvaluationResponse
Retrieves detailed information about a batch evaluation, including its status, configuration, results, and any error details.
-
#get_browser_session(params = {}) ⇒ Types::GetBrowserSessionResponse
Retrieves detailed information about a specific browser session in Amazon Bedrock AgentCore.
-
#get_code_interpreter_session(params = {}) ⇒ Types::GetCodeInterpreterSessionResponse
Retrieves detailed information about a specific code interpreter session in Amazon Bedrock AgentCore.
-
#get_event(params = {}) ⇒ Types::GetEventOutput
Retrieves information about a specific event in an AgentCore Memory resource.
-
#get_memory_record(params = {}) ⇒ Types::GetMemoryRecordOutput
Retrieves a specific memory record from an AgentCore Memory resource.
-
#get_payment_instrument(params = {}) ⇒ Types::GetPaymentInstrumentResponse
Get a payment instrument by ID.
-
#get_payment_instrument_balance(params = {}) ⇒ Types::GetPaymentInstrumentBalanceResponse
Get the balance of a payment instrument.
-
#get_payment_session(params = {}) ⇒ Types::GetPaymentSessionResponse
Get a payment session.
-
#get_recommendation(params = {}) ⇒ Types::GetRecommendationResponse
Retrieves detailed information about a recommendation, including its configuration, status, and results.
-
#get_resource_api_key(params = {}) ⇒ Types::GetResourceApiKeyResponse
Retrieves the API key associated with an API key credential provider.
-
#get_resource_oauth_2_token(params = {}) ⇒ Types::GetResourceOauth2TokenResponse
Returns the OAuth 2.0 token of the provided resource.
-
#get_resource_payment_token(params = {}) ⇒ Types::GetResourcePaymentTokenResponse
Generates authentication tokens for payment providers that use vendor-specific authentication mechanisms.
-
#get_workload_access_token(params = {}) ⇒ Types::GetWorkloadAccessTokenResponse
Obtains a workload access token for agentic workloads not acting on behalf of a user.
-
#get_workload_access_token_for_jwt(params = {}) ⇒ Types::GetWorkloadAccessTokenForJWTResponse
Obtains a workload access token for agentic workloads acting on behalf of a user, using a JWT token.
-
#get_workload_access_token_for_user_id(params = {}) ⇒ Types::GetWorkloadAccessTokenForUserIdResponse
Obtains a workload access token for agentic workloads acting on behalf of a user, using the user's ID.
-
#invoke_agent_runtime(params = {}) ⇒ Types::InvokeAgentRuntimeResponse
Sends a request to an agent or tool hosted in an Amazon Bedrock AgentCore Runtime and receives responses in real-time.
-
#invoke_agent_runtime_command(params = {}) ⇒ Types::InvokeAgentRuntimeCommandResponse
Executes a command in a runtime session container and streams the output back to the caller.
-
#invoke_browser(params = {}) ⇒ Types::InvokeBrowserResponse
Invokes an operating system-level action on a browser session in Amazon Bedrock AgentCore.
-
#invoke_code_interpreter(params = {}) ⇒ Types::InvokeCodeInterpreterResponse
Executes code within an active code interpreter session in Amazon Bedrock AgentCore.
-
#invoke_harness(params = {}) ⇒ Types::InvokeHarnessResponse
Operation to invoke a Harness.
-
#list_ab_tests(params = {}) ⇒ Types::ListABTestsResponse
Lists all A/B tests in the account.
-
#list_actors(params = {}) ⇒ Types::ListActorsOutput
Lists all actors in an AgentCore Memory resource.
-
#list_batch_evaluations(params = {}) ⇒ Types::ListBatchEvaluationsResponse
Lists all batch evaluations in the account, providing summary information about each evaluation's status and configuration.
-
#list_browser_sessions(params = {}) ⇒ Types::ListBrowserSessionsResponse
Retrieves a list of browser sessions in Amazon Bedrock AgentCore that match the specified criteria.
-
#list_code_interpreter_sessions(params = {}) ⇒ Types::ListCodeInterpreterSessionsResponse
Retrieves a list of code interpreter sessions in Amazon Bedrock AgentCore that match the specified criteria.
-
#list_events(params = {}) ⇒ Types::ListEventsOutput
Lists events in an AgentCore Memory resource based on specified criteria.
-
#list_memory_extraction_jobs(params = {}) ⇒ Types::ListMemoryExtractionJobsOutput
Lists all long-term memory extraction jobs that are eligible to be started with optional filtering.
-
#list_memory_records(params = {}) ⇒ Types::ListMemoryRecordsOutput
Lists memory records in an AgentCore Memory resource based on specified criteria.
-
#list_payment_instruments(params = {}) ⇒ Types::ListPaymentInstrumentsResponse
List payment instruments for a manager.
-
#list_payment_sessions(params = {}) ⇒ Types::ListPaymentSessionsResponse
List payment sessions.
-
#list_recommendations(params = {}) ⇒ Types::ListRecommendationsResponse
Lists all recommendations in the account, with optional filtering by status.
-
#list_sessions(params = {}) ⇒ Types::ListSessionsOutput
Lists sessions in an AgentCore Memory resource based on specified criteria.
-
#process_payment(params = {}) ⇒ Types::ProcessPaymentResponse
Processes a payment using a payment instrument within a payment session.
-
#retrieve_memory_records(params = {}) ⇒ Types::RetrieveMemoryRecordsOutput
Searches for and retrieves memory records from an AgentCore Memory resource based on specified search criteria.
-
#save_browser_session_profile(params = {}) ⇒ Types::SaveBrowserSessionProfileResponse
Saves the current state of a browser session as a reusable profile in Amazon Bedrock AgentCore.
-
#search_registry_records(params = {}) ⇒ Types::SearchRegistryRecordsResponse
Searches for registry records using semantic, lexical, or hybrid queries.
-
#start_batch_evaluation(params = {}) ⇒ Types::StartBatchEvaluationResponse
Starts a batch evaluation job that evaluates agent performance across multiple sessions.
-
#start_browser_session(params = {}) ⇒ Types::StartBrowserSessionResponse
Creates and initializes a browser session in Amazon Bedrock AgentCore.
-
#start_code_interpreter_session(params = {}) ⇒ Types::StartCodeInterpreterSessionResponse
Creates and initializes a code interpreter session in Amazon Bedrock AgentCore.
-
#start_memory_extraction_job(params = {}) ⇒ Types::StartMemoryExtractionJobOutput
Starts a memory extraction job that processes events that failed extraction previously in an AgentCore Memory resource and produces structured memory records.
-
#start_recommendation(params = {}) ⇒ Types::StartRecommendationResponse
Starts a recommendation job that analyzes agent traces and generates optimization suggestions for system prompts or tool descriptions to improve agent performance.
-
#stop_batch_evaluation(params = {}) ⇒ Types::StopBatchEvaluationResponse
Stops a running batch evaluation.
-
#stop_browser_session(params = {}) ⇒ Types::StopBrowserSessionResponse
Terminates an active browser session in Amazon Bedrock AgentCore.
-
#stop_code_interpreter_session(params = {}) ⇒ Types::StopCodeInterpreterSessionResponse
Terminates an active code interpreter session in Amazon Bedrock AgentCore.
-
#stop_runtime_session(params = {}) ⇒ Types::StopRuntimeSessionResponse
Stops a session that is running in an running AgentCore Runtime agent.
-
#update_ab_test(params = {}) ⇒ Types::UpdateABTestResponse
Updates an A/B test's configuration, including variants, traffic allocation, evaluation settings, or execution status.
-
#update_browser_stream(params = {}) ⇒ Types::UpdateBrowserStreamResponse
Updates a browser stream.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
482 483 484 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 482 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6400 6401 6402 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 6400 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6403 6404 6405 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 6403 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#batch_create_memory_records(params = {}) ⇒ Types::BatchCreateMemoryRecordsOutput
Creates multiple memory records in a single batch operation for the specified memory with custom content.
90 |
# File 'sig/client.rbs', line 90
def batch_create_memory_records: (
|
#batch_delete_memory_records(params = {}) ⇒ Types::BatchDeleteMemoryRecordsOutput
Deletes multiple memory records in a single batch operation from the specified memory.
119 |
# File 'sig/client.rbs', line 119
def batch_delete_memory_records: (
|
#batch_update_memory_records(params = {}) ⇒ Types::BatchUpdateMemoryRecordsOutput
Updates multiple memory records with custom content in a single batch operation within the specified memory.
135 |
# File 'sig/client.rbs', line 135
def batch_update_memory_records: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6373 6374 6375 6376 6377 6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 6373 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::BedrockAgentCore') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-bedrockagentcore' context[:gem_version] = '1.46.0' Seahorse::Client::Request.new(handlers, context) end |
#complete_resource_token_auth(params = {}) ⇒ Struct
Confirms the user authentication session for obtaining OAuth2.0 tokens for a resource.
161 |
# File 'sig/client.rbs', line 161
def complete_resource_token_auth: (
|
#create_ab_test(params = {}) ⇒ Types::CreateABTestResponse
Creates an A/B test for comparing agent configurations. A/B tests split traffic between a control variant and a treatment variant through a gateway, then evaluate performance using online evaluation configurations to determine which variant performs better.
180 |
# File 'sig/client.rbs', line 180
def create_ab_test: (
|
#create_event(params = {}) ⇒ Types::CreateEventOutput
Creates an event in an AgentCore Memory resource. Events represent interactions or activities that occur within a session and are associated with specific actors.
To use this operation, you must have the
bedrock-agentcore:CreateEvent permission.
This operation is subject to request rate limiting.
211 |
# File 'sig/client.rbs', line 211
def create_event: (
|
#create_payment_instrument(params = {}) ⇒ Types::CreatePaymentInstrumentResponse
Create a new payment instrument for a connector.
245 |
# File 'sig/client.rbs', line 245
def create_payment_instrument: (
|
#create_payment_session(params = {}) ⇒ Types::CreatePaymentSessionResponse
Create a new payment session.
313 |
# File 'sig/client.rbs', line 313
def create_payment_session: (
|
#delete_ab_test(params = {}) ⇒ Types::DeleteABTestResponse
Deletes an A/B test and its associated gateway rules.
335 |
# File 'sig/client.rbs', line 335
def delete_ab_test: (
|
#delete_batch_evaluation(params = {}) ⇒ Types::DeleteBatchEvaluationResponse
Deletes a batch evaluation and its associated results.
347 |
# File 'sig/client.rbs', line 347
def delete_batch_evaluation: (
|
#delete_capacity_provider_session(params = {}) ⇒ Types::DeleteCapacityProviderSessionResponse
Deletes a session associated with a capacity provider in Amazon Bedrock AgentCore and makes the session unavailable for further use. To delete a capacity provider session, specify both the capacity provider identifier and the session ID. After you delete a session, you cannot restart it.
359 |
# File 'sig/client.rbs', line 359
def delete_capacity_provider_session: (
|
#delete_event(params = {}) ⇒ Types::DeleteEventOutput
Deletes an event from an AgentCore Memory resource. When you delete an event, it is permanently removed.
To use this operation, you must have the
bedrock-agentcore:DeleteEvent permission.
370 |
# File 'sig/client.rbs', line 370
def delete_event: (
|
#delete_memory_record(params = {}) ⇒ Types::DeleteMemoryRecordOutput
Deletes a memory record from an AgentCore Memory resource. When you delete a memory record, it is permanently removed.
To use this operation, you must have the
bedrock-agentcore:DeleteMemoryRecord permission.
383 |
# File 'sig/client.rbs', line 383
def delete_memory_record: (
|
#delete_payment_instrument(params = {}) ⇒ Types::DeletePaymentInstrumentResponse
Deletes a payment instrument. This is a soft delete operation that preserves the record for audit and compliance purposes.
394 |
# File 'sig/client.rbs', line 394
def delete_payment_instrument: (
|
#delete_payment_session(params = {}) ⇒ Types::DeletePaymentSessionResponse
Deletes a payment session. This permanently removes the payment session record.
407 |
# File 'sig/client.rbs', line 407
def delete_payment_session: (
|
#delete_recommendation(params = {}) ⇒ Types::DeleteRecommendationResponse
Deletes a recommendation and its associated results.
420 |
# File 'sig/client.rbs', line 420
def delete_recommendation: (
|
#evaluate(params = {}) ⇒ Types::EvaluateResponse
Performs on-demand evaluation of agent traces using a specified evaluator. This synchronous API accepts traces in OpenTelemetry format and returns immediate scoring results with detailed explanations.
430 |
# File 'sig/client.rbs', line 430
def evaluate: (
|
#get_ab_test(params = {}) ⇒ Types::GetABTestResponse
Retrieves detailed information about an A/B test, including its configuration, status, and statistical results.
490 |
# File 'sig/client.rbs', line 490
def get_ab_test: (
|
#get_agent_card(params = {}) ⇒ Types::GetAgentCardResponse
Retrieves the A2A agent card associated with an AgentCore Runtime agent.
502 |
# File 'sig/client.rbs', line 502
def get_agent_card: (
|
#get_batch_evaluation(params = {}) ⇒ Types::GetBatchEvaluationResponse
Retrieves detailed information about a batch evaluation, including its status, configuration, results, and any error details.
530 |
# File 'sig/client.rbs', line 530
def get_batch_evaluation: (
|
#get_browser_session(params = {}) ⇒ Types::GetBrowserSessionResponse
Retrieves detailed information about a specific browser session in Amazon Bedrock AgentCore. This operation returns the session's configuration, current status, associated streams, and metadata.
To get a browser session, you must specify both the browser identifier and the session ID. The response includes information about the session's viewport configuration, timeout settings, and stream endpoints.
The following operations are related to GetBrowserSession:
555 |
# File 'sig/client.rbs', line 555
def get_browser_session: (
|
#get_code_interpreter_session(params = {}) ⇒ Types::GetCodeInterpreterSessionResponse
Retrieves detailed information about a specific code interpreter session in Amazon Bedrock AgentCore. This operation returns the session's configuration, current status, and metadata.
To get a code interpreter session, you must specify both the code interpreter identifier and the session ID. The response includes information about the session's timeout settings and current status.
The following operations are related to GetCodeInterpreterSession:
573 |
# File 'sig/client.rbs', line 573
def get_code_interpreter_session: (
|
#get_event(params = {}) ⇒ Types::GetEventOutput
Retrieves information about a specific event in an AgentCore Memory resource.
To use this operation, you must have the bedrock-agentcore:GetEvent
permission.
584 |
# File 'sig/client.rbs', line 584
def get_event: (
|
#get_memory_record(params = {}) ⇒ Types::GetMemoryRecordOutput
Retrieves a specific memory record from an AgentCore Memory resource.
To use this operation, you must have the
bedrock-agentcore:GetMemoryRecord permission.
597 |
# File 'sig/client.rbs', line 597
def get_memory_record: (
|
#get_payment_instrument(params = {}) ⇒ Types::GetPaymentInstrumentResponse
Get a payment instrument by ID.
608 |
# File 'sig/client.rbs', line 608
def get_payment_instrument: (
|
#get_payment_instrument_balance(params = {}) ⇒ Types::GetPaymentInstrumentBalanceResponse
Get the balance of a payment instrument.
623 |
# File 'sig/client.rbs', line 623
def get_payment_instrument_balance: (
|
#get_payment_session(params = {}) ⇒ Types::GetPaymentSessionResponse
Get a payment session.
639 |
# File 'sig/client.rbs', line 639
def get_payment_session: (
|
#get_recommendation(params = {}) ⇒ Types::GetRecommendationResponse
Retrieves detailed information about a recommendation, including its configuration, status, and results.
662 |
# File 'sig/client.rbs', line 662
def get_recommendation: (
|
#get_resource_api_key(params = {}) ⇒ Types::GetResourceApiKeyResponse
Retrieves the API key associated with an API key credential provider.
672 |
# File 'sig/client.rbs', line 672
def get_resource_api_key: (
|
#get_resource_oauth_2_token(params = {}) ⇒ Types::GetResourceOauth2TokenResponse
Returns the OAuth 2.0 token of the provided resource.
686 |
# File 'sig/client.rbs', line 686
def get_resource_oauth_2_token: (
|
#get_resource_payment_token(params = {}) ⇒ Types::GetResourcePaymentTokenResponse
Generates authentication tokens for payment providers that use vendor-specific authentication mechanisms.
706 |
# File 'sig/client.rbs', line 706
def get_resource_payment_token: (
|
#get_workload_access_token(params = {}) ⇒ Types::GetWorkloadAccessTokenResponse
Obtains a workload access token for agentic workloads not acting on behalf of a user.
732 |
# File 'sig/client.rbs', line 732
def get_workload_access_token: (
|
#get_workload_access_token_for_jwt(params = {}) ⇒ Types::GetWorkloadAccessTokenForJWTResponse
Obtains a workload access token for agentic workloads acting on behalf of a user, using a JWT token.
742 |
# File 'sig/client.rbs', line 742
def get_workload_access_token_for_jwt: (
|
#get_workload_access_token_for_user_id(params = {}) ⇒ Types::GetWorkloadAccessTokenForUserIdResponse
Obtains a workload access token for agentic workloads acting on behalf of a user, using the user's ID.
753 |
# File 'sig/client.rbs', line 753
def get_workload_access_token_for_user_id: (
|
#invoke_agent_runtime(params = {}) ⇒ Types::InvokeAgentRuntimeResponse
Sends a request to an agent or tool hosted in an Amazon Bedrock AgentCore Runtime and receives responses in real-time.
To invoke an agent, you can specify either the AgentCore Runtime ARN or the agent ID with an account ID, and provide a payload containing your request. When you use the agent ID instead of the full ARN, you don't need to URL-encode the identifier. You can optionally specify a qualifier to target a specific endpoint of the agent.
This operation supports streaming responses, allowing you to receive partial responses as they become available. We recommend using pagination to ensure that the operation returns quickly and successfully when processing large responses.
For example code, see Invoke an AgentCore Runtime agent.
If you're integrating your agent with OAuth, you can't use the
Amazon Web Services SDK to call InvokeAgentRuntime. Instead, make a
HTTPS request to InvokeAgentRuntime. For an example, see
Authenticate and authorize with Inbound Auth and Outbound Auth.
To use this operation, you must have the
bedrock-agentcore:InvokeAgentRuntime permission. If you are making a
call to InvokeAgentRuntime on behalf of a user ID with the
X-Amzn-Bedrock-AgentCore-Runtime-User-Id header, You require
permissions to both actions (bedrock-agentcore:InvokeAgentRuntime
and bedrock-agentcore:InvokeAgentRuntimeForUser).
773 |
# File 'sig/client.rbs', line 773
def invoke_agent_runtime: (
|
#invoke_agent_runtime_command(params = {}) ⇒ Types::InvokeAgentRuntimeCommandResponse
Executes a command in a runtime session container and streams the output back to the caller. This operation allows you to run shell commands within the agent runtime environment and receive real-time streaming responses including standard output and standard error.
To invoke a command, you must specify the agent runtime ARN and a
runtime session ID. The command execution supports streaming
responses, allowing you to receive output as it becomes available
through contentStart, contentDelta, and contentStop events.
To use this operation, you must have the
bedrock-agentcore:InvokeAgentRuntimeCommand permission.
805 |
# File 'sig/client.rbs', line 805
def invoke_agent_runtime_command: (
|
#invoke_browser(params = {}) ⇒ Types::InvokeBrowserResponse
Invokes an operating system-level action on a browser session in Amazon Bedrock AgentCore. This operation provides direct OS-level control over browser sessions, enabling mouse actions, keyboard input, and screenshots that the WebSocket-based Chrome DevTools Protocol (CDP) cannot handle — such as interacting with print dialogs, context menus, and JavaScript alerts.
You send a request with exactly one action in the BrowserAction
union, and receive a corresponding result in the BrowserActionResult
union.
The following operations are related to InvokeBrowser:
829 |
# File 'sig/client.rbs', line 829
def invoke_browser: (
|
#invoke_code_interpreter(params = {}) ⇒ Types::InvokeCodeInterpreterResponse
Executes code within an active code interpreter session in Amazon Bedrock AgentCore. This operation processes the provided code, runs it in a secure environment, and returns the execution results including output, errors, and generated visualizations.
To execute code, you must specify the code interpreter identifier, session ID, and the code to run in the arguments parameter. The operation returns a stream containing the execution results, which can include text output, error messages, and data visualizations.
This operation is subject to request rate limiting based on your account's service quotas.
The following operations are related to InvokeCodeInterpreter:
879 |
# File 'sig/client.rbs', line 879
def invoke_code_interpreter: (
|
#invoke_harness(params = {}) ⇒ Types::InvokeHarnessResponse
Operation to invoke a Harness.
911 |
# File 'sig/client.rbs', line 911
def invoke_harness: (
|
#list_ab_tests(params = {}) ⇒ Types::ListABTestsResponse
Lists all A/B tests in the account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1075 |
# File 'sig/client.rbs', line 1075
def list_ab_tests: (
|
#list_actors(params = {}) ⇒ Types::ListActorsOutput
Lists all actors in an AgentCore Memory resource. We recommend using pagination to ensure that the operation returns quickly and successfully.
To use this operation, you must have the
bedrock-agentcore:ListActors permission.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1087 |
# File 'sig/client.rbs', line 1087
def list_actors: (
|
#list_batch_evaluations(params = {}) ⇒ Types::ListBatchEvaluationsResponse
Lists all batch evaluations in the account, providing summary information about each evaluation's status and configuration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1100 |
# File 'sig/client.rbs', line 1100
def list_batch_evaluations: (
|
#list_browser_sessions(params = {}) ⇒ Types::ListBrowserSessionsResponse
Retrieves a list of browser sessions in Amazon Bedrock AgentCore that match the specified criteria. This operation returns summary information about each session, including identifiers, status, and timestamps.
You can filter the results by browser identifier and session status. The operation supports pagination to handle large result sets efficiently.
We recommend using pagination to ensure that the operation returns quickly and successfully when retrieving large numbers of sessions.
The following operations are related to ListBrowserSessions:
1112 |
# File 'sig/client.rbs', line 1112
def list_browser_sessions: (
|
#list_code_interpreter_sessions(params = {}) ⇒ Types::ListCodeInterpreterSessionsResponse
Retrieves a list of code interpreter sessions in Amazon Bedrock AgentCore that match the specified criteria. This operation returns summary information about each session, including identifiers, status, and timestamps.
You can filter the results by code interpreter identifier and session status. The operation supports pagination to handle large result sets efficiently.
We recommend using pagination to ensure that the operation returns quickly and successfully when retrieving large numbers of sessions.
The following operations are related to ListCodeInterpreterSessions:
1126 |
# File 'sig/client.rbs', line 1126
def list_code_interpreter_sessions: (
|
#list_events(params = {}) ⇒ Types::ListEventsOutput
Lists events in an AgentCore Memory resource based on specified criteria. We recommend using pagination to ensure that the operation returns quickly and successfully.
To use this operation, you must have the
bedrock-agentcore:ListEvents permission.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1140 |
# File 'sig/client.rbs', line 1140
def list_events: (
|
#list_memory_extraction_jobs(params = {}) ⇒ Types::ListMemoryExtractionJobsOutput
Lists all long-term memory extraction jobs that are eligible to be started with optional filtering.
To use this operation, you must have the
bedrock-agentcore:ListMemoryExtractionJobs permission.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1175 |
# File 'sig/client.rbs', line 1175
def list_memory_extraction_jobs: (
|
#list_memory_records(params = {}) ⇒ Types::ListMemoryRecordsOutput
Lists memory records in an AgentCore Memory resource based on specified criteria. We recommend using pagination to ensure that the operation returns quickly and successfully.
To use this operation, you must have the
bedrock-agentcore:ListMemoryRecords permission.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1194 |
# File 'sig/client.rbs', line 1194
def list_memory_records: (
|
#list_payment_instruments(params = {}) ⇒ Types::ListPaymentInstrumentsResponse
List payment instruments for a manager.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1213 |
# File 'sig/client.rbs', line 1213
def list_payment_instruments: (
|
#list_payment_sessions(params = {}) ⇒ Types::ListPaymentSessionsResponse
List payment sessions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1229 |
# File 'sig/client.rbs', line 1229
def list_payment_sessions: (
|
#list_recommendations(params = {}) ⇒ Types::ListRecommendationsResponse
Lists all recommendations in the account, with optional filtering by status.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1244 |
# File 'sig/client.rbs', line 1244
def list_recommendations: (
|
#list_sessions(params = {}) ⇒ Types::ListSessionsOutput
Lists sessions in an AgentCore Memory resource based on specified criteria. We recommend using pagination to ensure that the operation returns quickly and successfully.
Empty sessions are automatically deleted after one day.
To use this operation, you must have the
bedrock-agentcore:ListSessions permission.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1257 |
# File 'sig/client.rbs', line 1257
def list_sessions: (
|
#process_payment(params = {}) ⇒ Types::ProcessPaymentResponse
Processes a payment using a payment instrument within a payment session.
1281 |
# File 'sig/client.rbs', line 1281
def process_payment: (
|
#retrieve_memory_records(params = {}) ⇒ Types::RetrieveMemoryRecordsOutput
Searches for and retrieves memory records from an AgentCore Memory resource based on specified search criteria. We recommend using pagination to ensure that the operation returns quickly and successfully.
To use this operation, you must have the
bedrock-agentcore:RetrieveMemoryRecords permission.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1305 |
# File 'sig/client.rbs', line 1305
def retrieve_memory_records: (
|
#save_browser_session_profile(params = {}) ⇒ Types::SaveBrowserSessionProfileResponse
Saves the current state of a browser session as a reusable profile in Amazon Bedrock AgentCore. A browser profile captures persistent browser data such as cookies and local storage from an active session, enabling you to reuse this data in future browser sessions.
To save a browser session profile, you must specify the profile
identifier, browser identifier, and session ID. The session must be
active when saving the profile. Once saved, the profile can be used
with the StartBrowserSession operation to initialize new sessions
with the stored browser state.
Browser profiles are useful for scenarios that require persistent authentication, maintaining user preferences across sessions, or continuing tasks that depend on previously stored browser data.
The following operations are related to SaveBrowserSessionProfile:
1330 |
# File 'sig/client.rbs', line 1330
def save_browser_session_profile: (
|
#search_registry_records(params = {}) ⇒ Types::SearchRegistryRecordsResponse
Searches for registry records using semantic, lexical, or hybrid queries. Returns metadata for matching records ordered by relevance within the specified registry.
1345 |
# File 'sig/client.rbs', line 1345
def search_registry_records: (
|
#start_batch_evaluation(params = {}) ⇒ Types::StartBatchEvaluationResponse
Starts a batch evaluation job that evaluates agent performance across multiple sessions. Batch evaluations pull agent traces from CloudWatch Logs or an existing online evaluation configuration and run specified evaluators and insights against them.
1369 |
# File 'sig/client.rbs', line 1369
def start_batch_evaluation: (
|
#start_browser_session(params = {}) ⇒ Types::StartBrowserSessionResponse
Creates and initializes a browser session in Amazon Bedrock AgentCore. The session enables agents to navigate and interact with web content, extract information from websites, and perform web-based tasks as part of their response generation.
To create a session, you must specify a browser identifier and a name.
You can also configure the viewport dimensions to control the visible
area of web content. The session remains active until it times out or
you explicitly stop it using the StopBrowserSession operation.
The following operations are related to StartBrowserSession:
1447 |
# File 'sig/client.rbs', line 1447
def start_browser_session: (
|
#start_code_interpreter_session(params = {}) ⇒ Types::StartCodeInterpreterSessionResponse
Creates and initializes a code interpreter session in Amazon Bedrock AgentCore. The session enables agents to execute code as part of their response generation, supporting programming languages such as Python for data analysis, visualization, and computation tasks.
To create a session, you must specify a code interpreter identifier
and a name. The session remains active until it times out or you
explicitly stop it using the StopCodeInterpreterSession operation.
The following operations are related to StartCodeInterpreterSession:
1525 |
# File 'sig/client.rbs', line 1525
def start_code_interpreter_session: (
|
#start_memory_extraction_job(params = {}) ⇒ Types::StartMemoryExtractionJobOutput
Starts a memory extraction job that processes events that failed extraction previously in an AgentCore Memory resource and produces structured memory records. When earlier extraction attempts have left events unprocessed, this job will pick up and extract those as well.
To use this operation, you must have the
bedrock-agentcore:StartMemoryExtractionJob permission.
1552 |
# File 'sig/client.rbs', line 1552
def start_memory_extraction_job: (
|
#start_recommendation(params = {}) ⇒ Types::StartRecommendationResponse
Starts a recommendation job that analyzes agent traces and generates optimization suggestions for system prompts or tool descriptions to improve agent performance.
1574 |
# File 'sig/client.rbs', line 1574
def start_recommendation: (
|
#stop_batch_evaluation(params = {}) ⇒ Types::StopBatchEvaluationResponse
Stops a running batch evaluation. Sessions that have already been evaluated retain their results.
1637 |
# File 'sig/client.rbs', line 1637
def stop_batch_evaluation: (
|
#stop_browser_session(params = {}) ⇒ Types::StopBrowserSessionResponse
Terminates an active browser session in Amazon Bedrock AgentCore. This operation stops the session, releases associated resources, and makes the session unavailable for further use.
To stop a browser session, you must specify both the browser
identifier and the session ID. Once stopped, a session cannot be
restarted; you must create a new session using StartBrowserSession.
The following operations are related to StopBrowserSession:
1649 |
# File 'sig/client.rbs', line 1649
def stop_browser_session: (
|
#stop_code_interpreter_session(params = {}) ⇒ Types::StopCodeInterpreterSessionResponse
Terminates an active code interpreter session in Amazon Bedrock AgentCore. This operation stops the session, releases associated resources, and makes the session unavailable for further use.
To stop a code interpreter session, you must specify both the code
interpreter identifier and the session ID. Once stopped, a session
cannot be restarted; you must create a new session using
StartCodeInterpreterSession.
The following operations are related to StopCodeInterpreterSession:
1665 |
# File 'sig/client.rbs', line 1665
def stop_code_interpreter_session: (
|
#stop_runtime_session(params = {}) ⇒ Types::StopRuntimeSessionResponse
Stops a session that is running in an running AgentCore Runtime agent.
1680 |
# File 'sig/client.rbs', line 1680
def stop_runtime_session: (
|
#update_ab_test(params = {}) ⇒ Types::UpdateABTestResponse
Updates an A/B test's configuration, including variants, traffic allocation, evaluation settings, or execution status.
1697 |
# File 'sig/client.rbs', line 1697
def update_ab_test: (
|
#update_browser_stream(params = {}) ⇒ Types::UpdateBrowserStreamResponse
Updates a browser stream. To use this operation, you must have permissions to perform the bedrock:UpdateBrowserStream action.
1730 |
# File 'sig/client.rbs', line 1730
def update_browser_stream: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6393 6394 6395 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 6393 def waiter_names [] end |