Class: Aws::BedrockAgentCore::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::BedrockAgentCore::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-bedrockagentcore/client.rb
Overview
An API client for BedrockAgentCore. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::BedrockAgentCore::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_create_memory_records(params = {}) ⇒ Types::BatchCreateMemoryRecordsOutput
Creates multiple memory records in a single batch operation for the specified memory with custom content.
-
#batch_delete_memory_records(params = {}) ⇒ Types::BatchDeleteMemoryRecordsOutput
Deletes multiple memory records in a single batch operation from the specified memory.
-
#batch_update_memory_records(params = {}) ⇒ Types::BatchUpdateMemoryRecordsOutput
Updates multiple memory records with custom content in a single batch operation within the specified memory.
-
#complete_resource_token_auth(params = {}) ⇒ Struct
Confirms the user authentication session for obtaining OAuth2.0 tokens for a resource.
-
#create_ab_test(params = {}) ⇒ Types::CreateABTestResponse
Creates an A/B test for comparing agent configurations.
-
#create_event(params = {}) ⇒ Types::CreateEventOutput
Creates an event in an AgentCore Memory resource.
-
#create_payment_instrument(params = {}) ⇒ Types::CreatePaymentInstrumentResponse
Create a new payment instrument for a connector.
-
#create_payment_session(params = {}) ⇒ Types::CreatePaymentSessionResponse
Create a new payment session.
-
#delete_ab_test(params = {}) ⇒ Types::DeleteABTestResponse
Deletes an A/B test and its associated gateway rules.
-
#delete_batch_evaluation(params = {}) ⇒ Types::DeleteBatchEvaluationResponse
Deletes a batch evaluation and its associated results.
-
#delete_event(params = {}) ⇒ Types::DeleteEventOutput
Deletes an event from an AgentCore Memory resource.
-
#delete_memory_record(params = {}) ⇒ Types::DeleteMemoryRecordOutput
Deletes a memory record from an AgentCore Memory resource.
-
#delete_payment_instrument(params = {}) ⇒ Types::DeletePaymentInstrumentResponse
Deletes a payment instrument.
-
#delete_payment_session(params = {}) ⇒ Types::DeletePaymentSessionResponse
Deletes a payment session.
-
#delete_recommendation(params = {}) ⇒ Types::DeleteRecommendationResponse
Deletes a recommendation and its associated results.
-
#evaluate(params = {}) ⇒ Types::EvaluateResponse
Performs on-demand evaluation of agent traces using a specified evaluator.
-
#get_ab_test(params = {}) ⇒ Types::GetABTestResponse
Retrieves detailed information about an A/B test, including its configuration, status, and statistical results.
-
#get_agent_card(params = {}) ⇒ Types::GetAgentCardResponse
Retrieves the A2A agent card associated with an AgentCore Runtime agent.
-
#get_batch_evaluation(params = {}) ⇒ Types::GetBatchEvaluationResponse
Retrieves detailed information about a batch evaluation, including its status, configuration, results, and any error details.
-
#get_browser_session(params = {}) ⇒ Types::GetBrowserSessionResponse
Retrieves detailed information about a specific browser session in Amazon Bedrock AgentCore.
-
#get_code_interpreter_session(params = {}) ⇒ Types::GetCodeInterpreterSessionResponse
Retrieves detailed information about a specific code interpreter session in Amazon Bedrock AgentCore.
-
#get_event(params = {}) ⇒ Types::GetEventOutput
Retrieves information about a specific event in an AgentCore Memory resource.
-
#get_memory_record(params = {}) ⇒ Types::GetMemoryRecordOutput
Retrieves a specific memory record from an AgentCore Memory resource.
-
#get_payment_instrument(params = {}) ⇒ Types::GetPaymentInstrumentResponse
Get a payment instrument by ID.
-
#get_payment_instrument_balance(params = {}) ⇒ Types::GetPaymentInstrumentBalanceResponse
Get the balance of a payment instrument.
-
#get_payment_session(params = {}) ⇒ Types::GetPaymentSessionResponse
Get a payment session.
-
#get_recommendation(params = {}) ⇒ Types::GetRecommendationResponse
Retrieves detailed information about a recommendation, including its configuration, status, and results.
-
#get_resource_api_key(params = {}) ⇒ Types::GetResourceApiKeyResponse
Retrieves the API key associated with an API key credential provider.
-
#get_resource_oauth_2_token(params = {}) ⇒ Types::GetResourceOauth2TokenResponse
Returns the OAuth 2.0 token of the provided resource.
-
#get_resource_payment_token(params = {}) ⇒ Types::GetResourcePaymentTokenResponse
Generates authentication tokens for payment providers that use vendor-specific authentication mechanisms.
-
#get_workload_access_token(params = {}) ⇒ Types::GetWorkloadAccessTokenResponse
Obtains a workload access token for agentic workloads not acting on behalf of a user.
-
#get_workload_access_token_for_jwt(params = {}) ⇒ Types::GetWorkloadAccessTokenForJWTResponse
Obtains a workload access token for agentic workloads acting on behalf of a user, using a JWT token.
-
#get_workload_access_token_for_user_id(params = {}) ⇒ Types::GetWorkloadAccessTokenForUserIdResponse
Obtains a workload access token for agentic workloads acting on behalf of a user, using the user’s ID.
-
#invoke_agent_runtime(params = {}) ⇒ Types::InvokeAgentRuntimeResponse
Sends a request to an agent or tool hosted in an Amazon Bedrock AgentCore Runtime and receives responses in real-time.
-
#invoke_agent_runtime_command(params = {}) ⇒ Types::InvokeAgentRuntimeCommandResponse
Executes a command in a runtime session container and streams the output back to the caller.
-
#invoke_browser(params = {}) ⇒ Types::InvokeBrowserResponse
Invokes an operating system-level action on a browser session in Amazon Bedrock AgentCore.
-
#invoke_code_interpreter(params = {}) ⇒ Types::InvokeCodeInterpreterResponse
Executes code within an active code interpreter session in Amazon Bedrock AgentCore.
-
#invoke_harness(params = {}) ⇒ Types::InvokeHarnessResponse
Operation to invoke a Harness.
-
#list_ab_tests(params = {}) ⇒ Types::ListABTestsResponse
Lists all A/B tests in the account.
-
#list_actors(params = {}) ⇒ Types::ListActorsOutput
Lists all actors in an AgentCore Memory resource.
-
#list_batch_evaluations(params = {}) ⇒ Types::ListBatchEvaluationsResponse
Lists all batch evaluations in the account, providing summary information about each evaluation’s status and configuration.
-
#list_browser_sessions(params = {}) ⇒ Types::ListBrowserSessionsResponse
Retrieves a list of browser sessions in Amazon Bedrock AgentCore that match the specified criteria.
-
#list_code_interpreter_sessions(params = {}) ⇒ Types::ListCodeInterpreterSessionsResponse
Retrieves a list of code interpreter sessions in Amazon Bedrock AgentCore that match the specified criteria.
-
#list_events(params = {}) ⇒ Types::ListEventsOutput
Lists events in an AgentCore Memory resource based on specified criteria.
-
#list_memory_extraction_jobs(params = {}) ⇒ Types::ListMemoryExtractionJobsOutput
Lists all long-term memory extraction jobs that are eligible to be started with optional filtering.
-
#list_memory_records(params = {}) ⇒ Types::ListMemoryRecordsOutput
Lists memory records in an AgentCore Memory resource based on specified criteria.
-
#list_payment_instruments(params = {}) ⇒ Types::ListPaymentInstrumentsResponse
List payment instruments for a manager.
-
#list_payment_sessions(params = {}) ⇒ Types::ListPaymentSessionsResponse
List payment sessions.
-
#list_recommendations(params = {}) ⇒ Types::ListRecommendationsResponse
Lists all recommendations in the account, with optional filtering by status.
-
#list_sessions(params = {}) ⇒ Types::ListSessionsOutput
Lists sessions in an AgentCore Memory resource based on specified criteria.
-
#process_payment(params = {}) ⇒ Types::ProcessPaymentResponse
Processes a payment using a payment instrument within a payment session.
-
#retrieve_memory_records(params = {}) ⇒ Types::RetrieveMemoryRecordsOutput
Searches for and retrieves memory records from an AgentCore Memory resource based on specified search criteria.
-
#save_browser_session_profile(params = {}) ⇒ Types::SaveBrowserSessionProfileResponse
Saves the current state of a browser session as a reusable profile in Amazon Bedrock AgentCore.
-
#search_registry_records(params = {}) ⇒ Types::SearchRegistryRecordsResponse
Searches for registry records using semantic, lexical, or hybrid queries.
-
#start_batch_evaluation(params = {}) ⇒ Types::StartBatchEvaluationResponse
Starts a batch evaluation job that evaluates agent performance across multiple sessions.
-
#start_browser_session(params = {}) ⇒ Types::StartBrowserSessionResponse
Creates and initializes a browser session in Amazon Bedrock AgentCore.
-
#start_code_interpreter_session(params = {}) ⇒ Types::StartCodeInterpreterSessionResponse
Creates and initializes a code interpreter session in Amazon Bedrock AgentCore.
-
#start_memory_extraction_job(params = {}) ⇒ Types::StartMemoryExtractionJobOutput
Starts a memory extraction job that processes events that failed extraction previously in an AgentCore Memory resource and produces structured memory records.
-
#start_recommendation(params = {}) ⇒ Types::StartRecommendationResponse
Starts a recommendation job that analyzes agent traces and generates optimization suggestions for system prompts or tool descriptions to improve agent performance.
-
#stop_batch_evaluation(params = {}) ⇒ Types::StopBatchEvaluationResponse
Stops a running batch evaluation.
-
#stop_browser_session(params = {}) ⇒ Types::StopBrowserSessionResponse
Terminates an active browser session in Amazon Bedrock AgentCore.
-
#stop_code_interpreter_session(params = {}) ⇒ Types::StopCodeInterpreterSessionResponse
Terminates an active code interpreter session in Amazon Bedrock AgentCore.
-
#stop_runtime_session(params = {}) ⇒ Types::StopRuntimeSessionResponse
Stops a session that is running in an running AgentCore Runtime agent.
-
#update_ab_test(params = {}) ⇒ Types::UpdateABTestResponse
Updates an A/B test’s configuration, including variants, traffic allocation, evaluation settings, or execution status.
-
#update_browser_stream(params = {}) ⇒ Types::UpdateBrowserStreamResponse
Updates a browser stream.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
484 485 486 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 484 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6093 6094 6095 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 6093 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6096 6097 6098 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 6096 def errors_module Errors end |
Instance Method Details
#batch_create_memory_records(params = {}) ⇒ Types::BatchCreateMemoryRecordsOutput
Creates multiple memory records in a single batch operation for the specified memory with custom content.
557 558 559 560 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 557 def batch_create_memory_records(params = {}, = {}) req = build_request(:batch_create_memory_records, params) req.send_request() end |
#batch_delete_memory_records(params = {}) ⇒ Types::BatchDeleteMemoryRecordsOutput
Deletes multiple memory records in a single batch operation from the specified memory.
607 608 609 610 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 607 def batch_delete_memory_records(params = {}, = {}) req = build_request(:batch_delete_memory_records, params) req.send_request() end |
#batch_update_memory_records(params = {}) ⇒ Types::BatchUpdateMemoryRecordsOutput
Updates multiple memory records with custom content in a single batch operation within the specified memory.
671 672 673 674 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 671 def batch_update_memory_records(params = {}, = {}) req = build_request(:batch_update_memory_records, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6066 6067 6068 6069 6070 6071 6072 6073 6074 6075 6076 6077 6078 6079 6080 6081 6082 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 6066 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::BedrockAgentCore') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-bedrockagentcore' context[:gem_version] = '1.34.0' Seahorse::Client::Request.new(handlers, context) end |
#complete_resource_token_auth(params = {}) ⇒ Struct
Confirms the user authentication session for obtaining OAuth2.0 tokens for a resource.
706 707 708 709 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 706 def complete_resource_token_auth(params = {}, = {}) req = build_request(:complete_resource_token_auth, params) req.send_request() end |
#create_ab_test(params = {}) ⇒ Types::CreateABTestResponse
Creates an A/B test for comparing agent configurations. A/B tests split traffic between a control variant and a treatment variant through a gateway, then evaluate performance using online evaluation configurations to determine which variant performs better.
816 817 818 819 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 816 def create_ab_test(params = {}, = {}) req = build_request(:create_ab_test, params) req.send_request() end |
#create_event(params = {}) ⇒ Types::CreateEventOutput
Creates an event in an AgentCore Memory resource. Events represent interactions or activities that occur within a session and are associated with specific actors.
To use this operation, you must have the ‘bedrock-agentcore:CreateEvent` permission.
This operation is subject to request rate limiting.
920 921 922 923 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 920 def create_event(params = {}, = {}) req = build_request(:create_event, params) req.send_request() end |
#create_payment_instrument(params = {}) ⇒ Types::CreatePaymentInstrumentResponse
Create a new payment instrument for a connector.
1063 1064 1065 1066 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 1063 def create_payment_instrument(params = {}, = {}) req = build_request(:create_payment_instrument, params) req.send_request() end |
#create_payment_session(params = {}) ⇒ Types::CreatePaymentSessionResponse
Create a new payment session.
1131 1132 1133 1134 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 1131 def create_payment_session(params = {}, = {}) req = build_request(:create_payment_session, params) req.send_request() end |
#delete_ab_test(params = {}) ⇒ Types::DeleteABTestResponse
Deletes an A/B test and its associated gateway rules.
1163 1164 1165 1166 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 1163 def delete_ab_test(params = {}, = {}) req = build_request(:delete_ab_test, params) req.send_request() end |
#delete_batch_evaluation(params = {}) ⇒ Types::DeleteBatchEvaluationResponse
Deletes a batch evaluation and its associated results.
1195 1196 1197 1198 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 1195 def delete_batch_evaluation(params = {}, = {}) req = build_request(:delete_batch_evaluation, params) req.send_request() end |
#delete_event(params = {}) ⇒ Types::DeleteEventOutput
Deletes an event from an AgentCore Memory resource. When you delete an event, it is permanently removed.
To use this operation, you must have the ‘bedrock-agentcore:DeleteEvent` permission.
1240 1241 1242 1243 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 1240 def delete_event(params = {}, = {}) req = build_request(:delete_event, params) req.send_request() end |
#delete_memory_record(params = {}) ⇒ Types::DeleteMemoryRecordOutput
Deletes a memory record from an AgentCore Memory resource. When you delete a memory record, it is permanently removed.
To use this operation, you must have the ‘bedrock-agentcore:DeleteMemoryRecord` permission.
1277 1278 1279 1280 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 1277 def delete_memory_record(params = {}, = {}) req = build_request(:delete_memory_record, params) req.send_request() end |
#delete_payment_instrument(params = {}) ⇒ Types::DeletePaymentInstrumentResponse
Deletes a payment instrument. This is a soft delete operation that preserves the record for audit and compliance purposes.
1321 1322 1323 1324 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 1321 def delete_payment_instrument(params = {}, = {}) req = build_request(:delete_payment_instrument, params) req.send_request() end |
#delete_payment_session(params = {}) ⇒ Types::DeletePaymentSessionResponse
Deletes a payment session. This permanently removes the payment session record.
1359 1360 1361 1362 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 1359 def delete_payment_session(params = {}, = {}) req = build_request(:delete_payment_session, params) req.send_request() end |
#delete_recommendation(params = {}) ⇒ Types::DeleteRecommendationResponse
Deletes a recommendation and its associated results.
1389 1390 1391 1392 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 1389 def delete_recommendation(params = {}, = {}) req = build_request(:delete_recommendation, params) req.send_request() end |
#evaluate(params = {}) ⇒ Types::EvaluateResponse
Performs on-demand evaluation of agent traces using a specified evaluator. This synchronous API accepts traces in OpenTelemetry format and returns immediate scoring results with detailed explanations.
1490 1491 1492 1493 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 1490 def evaluate(params = {}, = {}) req = build_request(:evaluate, params) req.send_request() end |
#get_ab_test(params = {}) ⇒ Types::GetABTestResponse
Retrieves detailed information about an A/B test, including its configuration, status, and statistical results.
1580 1581 1582 1583 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 1580 def get_ab_test(params = {}, = {}) req = build_request(:get_ab_test, params) req.send_request() end |
#get_agent_card(params = {}) ⇒ Types::GetAgentCardResponse
Retrieves the A2A agent card associated with an AgentCore Runtime agent.
1625 1626 1627 1628 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 1625 def get_agent_card(params = {}, = {}) req = build_request(:get_agent_card, params) req.send_request() end |
#get_batch_evaluation(params = {}) ⇒ Types::GetBatchEvaluationResponse
Retrieves detailed information about a batch evaluation, including its status, configuration, results, and any error details.
1695 1696 1697 1698 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 1695 def get_batch_evaluation(params = {}, = {}) req = build_request(:get_batch_evaluation, params) req.send_request() end |
#get_browser_session(params = {}) ⇒ Types::GetBrowserSessionResponse
Retrieves detailed information about a specific browser session in Amazon Bedrock AgentCore. This operation returns the session’s configuration, current status, associated streams, and metadata.
To get a browser session, you must specify both the browser identifier and the session ID. The response includes information about the session’s viewport configuration, timeout settings, and stream endpoints.
The following operations are related to ‘GetBrowserSession`:
- StartBrowserSession][1
- ListBrowserSessions][2
- StopBrowserSession][3
[1]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_StartBrowserSession.html [2]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_ListBrowserSessions.html [3]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_StopBrowserSession.html
1794 1795 1796 1797 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 1794 def get_browser_session(params = {}, = {}) req = build_request(:get_browser_session, params) req.send_request() end |
#get_code_interpreter_session(params = {}) ⇒ Types::GetCodeInterpreterSessionResponse
Retrieves detailed information about a specific code interpreter session in Amazon Bedrock AgentCore. This operation returns the session’s configuration, current status, and metadata.
To get a code interpreter session, you must specify both the code interpreter identifier and the session ID. The response includes information about the session’s timeout settings and current status.
The following operations are related to ‘GetCodeInterpreterSession`:
- StartCodeInterpreterSession][1
- ListCodeInterpreterSessions][2
- StopCodeInterpreterSession][3
[1]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_StartCodeInterpreterSession.html [2]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_ListCodeInterpreterSessions.html [3]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_StopCodeInterpreterSession.html
1860 1861 1862 1863 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 1860 def get_code_interpreter_session(params = {}, = {}) req = build_request(:get_code_interpreter_session, params) req.send_request() end |
#get_event(params = {}) ⇒ Types::GetEventOutput
Retrieves information about a specific event in an AgentCore Memory resource.
To use this operation, you must have the ‘bedrock-agentcore:GetEvent` permission.
1915 1916 1917 1918 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 1915 def get_event(params = {}, = {}) req = build_request(:get_event, params) req.send_request() end |
#get_memory_record(params = {}) ⇒ Types::GetMemoryRecordOutput
Retrieves a specific memory record from an AgentCore Memory resource.
To use this operation, you must have the ‘bedrock-agentcore:GetMemoryRecord` permission.
1962 1963 1964 1965 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 1962 def get_memory_record(params = {}, = {}) req = build_request(:get_memory_record, params) req.send_request() end |
#get_payment_instrument(params = {}) ⇒ Types::GetPaymentInstrumentResponse
Get a payment instrument by ID.
2041 2042 2043 2044 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 2041 def get_payment_instrument(params = {}, = {}) req = build_request(:get_payment_instrument, params) req.send_request() end |
#get_payment_instrument_balance(params = {}) ⇒ Types::GetPaymentInstrumentBalanceResponse
Get the balance of a payment instrument.
2101 2102 2103 2104 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 2101 def get_payment_instrument_balance(params = {}, = {}) req = build_request(:get_payment_instrument_balance, params) req.send_request() end |
#get_payment_session(params = {}) ⇒ Types::GetPaymentSessionResponse
Get a payment session.
2151 2152 2153 2154 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 2151 def get_payment_session(params = {}, = {}) req = build_request(:get_payment_session, params) req.send_request() end |
#get_recommendation(params = {}) ⇒ Types::GetRecommendationResponse
Retrieves detailed information about a recommendation, including its configuration, status, and results.
2248 2249 2250 2251 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 2248 def get_recommendation(params = {}, = {}) req = build_request(:get_recommendation, params) req.send_request() end |
#get_resource_api_key(params = {}) ⇒ Types::GetResourceApiKeyResponse
Retrieves the API key associated with an API key credential provider.
2282 2283 2284 2285 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 2282 def get_resource_api_key(params = {}, = {}) req = build_request(:get_resource_api_key, params) req.send_request() end |
#get_resource_oauth_2_token(params = {}) ⇒ Types::GetResourceOauth2TokenResponse
Returns the OAuth 2.0 token of the provided resource.
2373 2374 2375 2376 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 2373 def get_resource_oauth_2_token(params = {}, = {}) req = build_request(:get_resource_oauth_2_token, params) req.send_request() end |
#get_resource_payment_token(params = {}) ⇒ Types::GetResourcePaymentTokenResponse
Generates authentication tokens for payment providers that use vendor-specific authentication mechanisms.
2430 2431 2432 2433 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 2430 def get_resource_payment_token(params = {}, = {}) req = build_request(:get_resource_payment_token, params) req.send_request() end |
#get_workload_access_token(params = {}) ⇒ Types::GetWorkloadAccessTokenResponse
Obtains a workload access token for agentic workloads not acting on behalf of a user.
2459 2460 2461 2462 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 2459 def get_workload_access_token(params = {}, = {}) req = build_request(:get_workload_access_token, params) req.send_request() end |
#get_workload_access_token_for_jwt(params = {}) ⇒ Types::GetWorkloadAccessTokenForJWTResponse
Obtains a workload access token for agentic workloads acting on behalf of a user, using a JWT token.
2492 2493 2494 2495 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 2492 def get_workload_access_token_for_jwt(params = {}, = {}) req = build_request(:get_workload_access_token_for_jwt, params) req.send_request() end |
#get_workload_access_token_for_user_id(params = {}) ⇒ Types::GetWorkloadAccessTokenForUserIdResponse
Obtains a workload access token for agentic workloads acting on behalf of a user, using the user’s ID.
2526 2527 2528 2529 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 2526 def get_workload_access_token_for_user_id(params = {}, = {}) req = build_request(:get_workload_access_token_for_user_id, params) req.send_request() end |
#invoke_agent_runtime(params = {}) ⇒ Types::InvokeAgentRuntimeResponse
Sends a request to an agent or tool hosted in an Amazon Bedrock AgentCore Runtime and receives responses in real-time.
To invoke an agent, you can specify either the AgentCore Runtime ARN or the agent ID with an account ID, and provide a payload containing your request. When you use the agent ID instead of the full ARN, you don’t need to URL-encode the identifier. You can optionally specify a qualifier to target a specific endpoint of the agent.
This operation supports streaming responses, allowing you to receive partial responses as they become available. We recommend using pagination to ensure that the operation returns quickly and successfully when processing large responses.
For example code, see [Invoke an AgentCore Runtime agent].
If you’re integrating your agent with OAuth, you can’t use the Amazon Web Services SDK to call ‘InvokeAgentRuntime`. Instead, make a HTTPS request to `InvokeAgentRuntime`. For an example, see [Authenticate and authorize with Inbound Auth and Outbound Auth].
To use this operation, you must have the ‘bedrock-agentcore:InvokeAgentRuntime` permission. If you are making a call to `InvokeAgentRuntime` on behalf of a user ID with the `X-Amzn-Bedrock-AgentCore-Runtime-User-Id` header, You require permissions to both actions (`bedrock-agentcore:InvokeAgentRuntime` and `bedrock-agentcore:InvokeAgentRuntimeForUser`).
[1]: docs.aws.amazon.com/bedrock-agentcore/latest/devguide/runtime-invoke-agent.html [2]: docs.aws.amazon.com/bedrock-agentcore/latest/devguide/runtime-oauth.html
2672 2673 2674 2675 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 2672 def invoke_agent_runtime(params = {}, = {}, &block) req = build_request(:invoke_agent_runtime, params) req.send_request(, &block) end |
#invoke_agent_runtime_command(params = {}) ⇒ Types::InvokeAgentRuntimeCommandResponse
Executes a command in a runtime session container and streams the output back to the caller. This operation allows you to run shell commands within the agent runtime environment and receive real-time streaming responses including standard output and standard error.
To invoke a command, you must specify the agent runtime ARN and a runtime session ID. The command execution supports streaming responses, allowing you to receive output as it becomes available through ‘contentStart`, `contentDelta`, and `contentStop` events.
To use this operation, you must have the ‘bedrock-agentcore:InvokeAgentRuntimeCommand` permission.
2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 2984 2985 2986 2987 2988 2989 2990 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 2969 def invoke_agent_runtime_command(params = {}, = {}, &block) params = params.dup event_stream_handler = case handler = params.delete(:event_stream_handler) when EventStreams::InvokeAgentRuntimeCommandStreamOutput then handler when Proc then EventStreams::InvokeAgentRuntimeCommandStreamOutput.new.tap(&handler) when nil then EventStreams::InvokeAgentRuntimeCommandStreamOutput.new else msg = "expected :event_stream_handler to be a block or "\ "instance of Aws::BedrockAgentCore::EventStreams::InvokeAgentRuntimeCommandStreamOutput"\ ", got `#{handler.inspect}` instead" raise ArgumentError, msg end yield(event_stream_handler) if block_given? req = build_request(:invoke_agent_runtime_command, params) req.context[:event_stream_handler] = event_stream_handler req.handlers.add(Aws::Binary::DecodeHandler, priority: 95) req.send_request(, &block) end |
#invoke_browser(params = {}) ⇒ Types::InvokeBrowserResponse
Invokes an operating system-level action on a browser session in Amazon Bedrock AgentCore. This operation provides direct OS-level control over browser sessions, enabling mouse actions, keyboard input, and screenshots that the WebSocket-based Chrome DevTools Protocol (CDP) cannot handle — such as interacting with print dialogs, context menus, and JavaScript alerts.
You send a request with exactly one action in the ‘BrowserAction` union, and receive a corresponding result in the `BrowserActionResult` union.
The following operations are related to ‘InvokeBrowser`:
- StartBrowserSession][1
- GetBrowserSession][2
- StopBrowserSession][3
[1]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_StartBrowserSession.html [2]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_GetBrowserSession.html [3]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_StopBrowserSession.html
3106 3107 3108 3109 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 3106 def invoke_browser(params = {}, = {}) req = build_request(:invoke_browser, params) req.send_request() end |
#invoke_code_interpreter(params = {}) ⇒ Types::InvokeCodeInterpreterResponse
Executes code within an active code interpreter session in Amazon Bedrock AgentCore. This operation processes the provided code, runs it in a secure environment, and returns the execution results including output, errors, and generated visualizations.
To execute code, you must specify the code interpreter identifier, session ID, and the code to run in the arguments parameter. The operation returns a stream containing the execution results, which can include text output, error messages, and data visualizations.
This operation is subject to request rate limiting based on your account’s service quotas.
The following operations are related to ‘InvokeCodeInterpreter`:
- StartCodeInterpreterSession][1
- GetCodeInterpreterSession][2
[1]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_StartCodeInterpreterSession.html [2]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_GetCodeInterpreterSession.html
3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 3426 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 3405 def invoke_code_interpreter(params = {}, = {}, &block) params = params.dup event_stream_handler = case handler = params.delete(:event_stream_handler) when EventStreams::CodeInterpreterStreamOutput then handler when Proc then EventStreams::CodeInterpreterStreamOutput.new.tap(&handler) when nil then EventStreams::CodeInterpreterStreamOutput.new else msg = "expected :event_stream_handler to be a block or "\ "instance of Aws::BedrockAgentCore::EventStreams::CodeInterpreterStreamOutput"\ ", got `#{handler.inspect}` instead" raise ArgumentError, msg end yield(event_stream_handler) if block_given? req = build_request(:invoke_code_interpreter, params) req.context[:event_stream_handler] = event_stream_handler req.handlers.add(Aws::Binary::DecodeHandler, priority: 95) req.send_request(, &block) end |
#invoke_harness(params = {}) ⇒ Types::InvokeHarnessResponse
Operation to invoke a Harness.
3825 3826 3827 3828 3829 3830 3831 3832 3833 3834 3835 3836 3837 3838 3839 3840 3841 3842 3843 3844 3845 3846 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 3825 def invoke_harness(params = {}, = {}, &block) params = params.dup event_stream_handler = case handler = params.delete(:event_stream_handler) when EventStreams::InvokeHarnessStreamOutput then handler when Proc then EventStreams::InvokeHarnessStreamOutput.new.tap(&handler) when nil then EventStreams::InvokeHarnessStreamOutput.new else msg = "expected :event_stream_handler to be a block or "\ "instance of Aws::BedrockAgentCore::EventStreams::InvokeHarnessStreamOutput"\ ", got `#{handler.inspect}` instead" raise ArgumentError, msg end yield(event_stream_handler) if block_given? req = build_request(:invoke_harness, params) req.context[:event_stream_handler] = event_stream_handler req.handlers.add(Aws::Binary::DecodeHandler, priority: 95) req.send_request(, &block) end |
#list_ab_tests(params = {}) ⇒ Types::ListABTestsResponse
Lists all A/B tests in the account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3894 3895 3896 3897 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 3894 def list_ab_tests(params = {}, = {}) req = build_request(:list_ab_tests, params) req.send_request() end |
#list_actors(params = {}) ⇒ Types::ListActorsOutput
Lists all actors in an AgentCore Memory resource. We recommend using pagination to ensure that the operation returns quickly and successfully.
To use this operation, you must have the ‘bedrock-agentcore:ListActors` permission.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3944 3945 3946 3947 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 3944 def list_actors(params = {}, = {}) req = build_request(:list_actors, params) req.send_request() end |
#list_batch_evaluations(params = {}) ⇒ Types::ListBatchEvaluationsResponse
Lists all batch evaluations in the account, providing summary information about each evaluation’s status and configuration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4008 4009 4010 4011 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 4008 def list_batch_evaluations(params = {}, = {}) req = build_request(:list_batch_evaluations, params) req.send_request() end |
#list_browser_sessions(params = {}) ⇒ Types::ListBrowserSessionsResponse
Retrieves a list of browser sessions in Amazon Bedrock AgentCore that match the specified criteria. This operation returns summary information about each session, including identifiers, status, and timestamps.
You can filter the results by browser identifier and session status. The operation supports pagination to handle large result sets efficiently.
We recommend using pagination to ensure that the operation returns quickly and successfully when retrieving large numbers of sessions.
The following operations are related to ‘ListBrowserSessions`:
- StartBrowserSession][1
- GetBrowserSession][2
[1]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_StartBrowserSession.html [2]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_GetBrowserSession.html
4087 4088 4089 4090 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 4087 def list_browser_sessions(params = {}, = {}) req = build_request(:list_browser_sessions, params) req.send_request() end |
#list_code_interpreter_sessions(params = {}) ⇒ Types::ListCodeInterpreterSessionsResponse
Retrieves a list of code interpreter sessions in Amazon Bedrock AgentCore that match the specified criteria. This operation returns summary information about each session, including identifiers, status, and timestamps.
You can filter the results by code interpreter identifier and session status. The operation supports pagination to handle large result sets efficiently.
We recommend using pagination to ensure that the operation returns quickly and successfully when retrieving large numbers of sessions.
The following operations are related to ‘ListCodeInterpreterSessions`:
- StartCodeInterpreterSession][1
- GetCodeInterpreterSession][2
[1]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_StartCodeInterpreterSession.html [2]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_GetCodeInterpreterSession.html
4166 4167 4168 4169 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 4166 def list_code_interpreter_sessions(params = {}, = {}) req = build_request(:list_code_interpreter_sessions, params) req.send_request() end |
#list_events(params = {}) ⇒ Types::ListEventsOutput
Lists events in an AgentCore Memory resource based on specified criteria. We recommend using pagination to ensure that the operation returns quickly and successfully.
To use this operation, you must have the ‘bedrock-agentcore:ListEvents` permission.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4262 4263 4264 4265 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 4262 def list_events(params = {}, = {}) req = build_request(:list_events, params) req.send_request() end |
#list_memory_extraction_jobs(params = {}) ⇒ Types::ListMemoryExtractionJobsOutput
Lists all long-term memory extraction jobs that are eligible to be started with optional filtering.
To use this operation, you must have the ‘bedrock-agentcore:ListMemoryExtractionJobs` permission.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4327 4328 4329 4330 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 4327 def list_memory_extraction_jobs(params = {}, = {}) req = build_request(:list_memory_extraction_jobs, params) req.send_request() end |
#list_memory_records(params = {}) ⇒ Types::ListMemoryRecordsOutput
Lists memory records in an AgentCore Memory resource based on specified criteria. We recommend using pagination to ensure that the operation returns quickly and successfully.
To use this operation, you must have the ‘bedrock-agentcore:ListMemoryRecords` permission.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4426 4427 4428 4429 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 4426 def list_memory_records(params = {}, = {}) req = build_request(:list_memory_records, params) req.send_request() end |
#list_payment_instruments(params = {}) ⇒ Types::ListPaymentInstrumentsResponse
List payment instruments for a manager.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4486 4487 4488 4489 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 4486 def list_payment_instruments(params = {}, = {}) req = build_request(:list_payment_instruments, params) req.send_request() end |
#list_payment_sessions(params = {}) ⇒ Types::ListPaymentSessionsResponse
List payment sessions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4540 4541 4542 4543 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 4540 def list_payment_sessions(params = {}, = {}) req = build_request(:list_payment_sessions, params) req.send_request() end |
#list_recommendations(params = {}) ⇒ Types::ListRecommendationsResponse
Lists all recommendations in the account, with optional filtering by status.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4596 4597 4598 4599 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 4596 def list_recommendations(params = {}, = {}) req = build_request(:list_recommendations, params) req.send_request() end |
#list_sessions(params = {}) ⇒ Types::ListSessionsOutput
Lists sessions in an AgentCore Memory resource based on specified criteria. We recommend using pagination to ensure that the operation returns quickly and successfully.
Empty sessions are automatically deleted after one day.
To use this operation, you must have the ‘bedrock-agentcore:ListSessions` permission.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4660 4661 4662 4663 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 4660 def list_sessions(params = {}, = {}) req = build_request(:list_sessions, params) req.send_request() end |
#process_payment(params = {}) ⇒ Types::ProcessPaymentResponse
Processes a payment using a payment instrument within a payment session.
4743 4744 4745 4746 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 4743 def process_payment(params = {}, = {}) req = build_request(:process_payment, params) req.send_request() end |
#retrieve_memory_records(params = {}) ⇒ Types::RetrieveMemoryRecordsOutput
Searches for and retrieves memory records from an AgentCore Memory resource based on specified search criteria. We recommend using pagination to ensure that the operation returns quickly and successfully.
To use this operation, you must have the ‘bedrock-agentcore:RetrieveMemoryRecords` permission.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4844 4845 4846 4847 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 4844 def retrieve_memory_records(params = {}, = {}) req = build_request(:retrieve_memory_records, params) req.send_request() end |
#save_browser_session_profile(params = {}) ⇒ Types::SaveBrowserSessionProfileResponse
Saves the current state of a browser session as a reusable profile in Amazon Bedrock AgentCore. A browser profile captures persistent browser data such as cookies and local storage from an active session, enabling you to reuse this data in future browser sessions.
To save a browser session profile, you must specify the profile identifier, browser identifier, and session ID. The session must be active when saving the profile. Once saved, the profile can be used with the ‘StartBrowserSession` operation to initialize new sessions with the stored browser state.
Browser profiles are useful for scenarios that require persistent authentication, maintaining user preferences across sessions, or continuing tasks that depend on previously stored browser data.
The following operations are related to ‘SaveBrowserSessionProfile`:
- StartBrowserSession][1
- GetBrowserSession][2
[1]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_StartBrowserSession.html [2]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_GetBrowserSession.html
4934 4935 4936 4937 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 4934 def save_browser_session_profile(params = {}, = {}) req = build_request(:save_browser_session_profile, params) req.send_request() end |
#search_registry_records(params = {}) ⇒ Types::SearchRegistryRecordsResponse
Searches for registry records using semantic, lexical, or hybrid queries. Returns metadata for matching records ordered by relevance within the specified registry.
5012 5013 5014 5015 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 5012 def search_registry_records(params = {}, = {}) req = build_request(:search_registry_records, params) req.send_request() end |
#start_batch_evaluation(params = {}) ⇒ Types::StartBatchEvaluationResponse
Starts a batch evaluation job that evaluates agent performance across multiple sessions. Batch evaluations pull agent traces from CloudWatch Logs or an existing online evaluation configuration and run specified evaluators and insights against them.
5137 5138 5139 5140 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 5137 def start_batch_evaluation(params = {}, = {}) req = build_request(:start_batch_evaluation, params) req.send_request() end |
#start_browser_session(params = {}) ⇒ Types::StartBrowserSessionResponse
Creates and initializes a browser session in Amazon Bedrock AgentCore. The session enables agents to navigate and interact with web content, extract information from websites, and perform web-based tasks as part of their response generation.
To create a session, you must specify a browser identifier and a name. You can also configure the viewport dimensions to control the visible area of web content. The session remains active until it times out or you explicitly stop it using the ‘StopBrowserSession` operation.
The following operations are related to ‘StartBrowserSession`:
- GetBrowserSession][1
- UpdateBrowserStream][2
- SaveBrowserSessionProfile][3
- StopBrowserSession][4
- InvokeBrowser][5
[1]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_GetBrowserSession.html [2]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_UpdateBrowserStream.html [3]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_SaveBrowserSessionProfile.html [4]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_StopBrowserSession.html [5]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_InvokeBrowser.html
5322 5323 5324 5325 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 5322 def start_browser_session(params = {}, = {}) req = build_request(:start_browser_session, params) req.send_request() end |
#start_code_interpreter_session(params = {}) ⇒ Types::StartCodeInterpreterSessionResponse
Creates and initializes a code interpreter session in Amazon Bedrock AgentCore. The session enables agents to execute code as part of their response generation, supporting programming languages such as Python for data analysis, visualization, and computation tasks.
To create a session, you must specify a code interpreter identifier and a name. The session remains active until it times out or you explicitly stop it using the ‘StopCodeInterpreterSession` operation.
The following operations are related to ‘StartCodeInterpreterSession`:
- InvokeCodeInterpreter][1
- GetCodeInterpreterSession][2
- StopCodeInterpreterSession][3
[1]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_InvokeCodeInterpreter.html [2]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_GetCodeInterpreterSession.html [3]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_StopCodeInterpreterSession.html
5420 5421 5422 5423 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 5420 def start_code_interpreter_session(params = {}, = {}) req = build_request(:start_code_interpreter_session, params) req.send_request() end |
#start_memory_extraction_job(params = {}) ⇒ Types::StartMemoryExtractionJobOutput
Starts a memory extraction job that processes events that failed extraction previously in an AgentCore Memory resource and produces structured memory records. When earlier extraction attempts have left events unprocessed, this job will pick up and extract those as well.
To use this operation, you must have the ‘bedrock-agentcore:StartMemoryExtractionJob` permission.
5469 5470 5471 5472 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 5469 def start_memory_extraction_job(params = {}, = {}) req = build_request(:start_memory_extraction_job, params) req.send_request() end |
#start_recommendation(params = {}) ⇒ Types::StartRecommendationResponse
Starts a recommendation job that analyzes agent traces and generates optimization suggestions for system prompts or tool descriptions to improve agent performance.
5671 5672 5673 5674 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 5671 def start_recommendation(params = {}, = {}) req = build_request(:start_recommendation, params) req.send_request() end |
#stop_batch_evaluation(params = {}) ⇒ Types::StopBatchEvaluationResponse
Stops a running batch evaluation. Sessions that have already been evaluated retain their results.
5706 5707 5708 5709 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 5706 def stop_batch_evaluation(params = {}, = {}) req = build_request(:stop_batch_evaluation, params) req.send_request() end |
#stop_browser_session(params = {}) ⇒ Types::StopBrowserSessionResponse
Terminates an active browser session in Amazon Bedrock AgentCore. This operation stops the session, releases associated resources, and makes the session unavailable for further use.
To stop a browser session, you must specify both the browser identifier and the session ID. Once stopped, a session cannot be restarted; you must create a new session using ‘StartBrowserSession`.
The following operations are related to ‘StopBrowserSession`:
- StartBrowserSession][1
- GetBrowserSession][2
[1]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_StartBrowserSession.html [2]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_GetBrowserSession.html
5777 5778 5779 5780 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 5777 def stop_browser_session(params = {}, = {}) req = build_request(:stop_browser_session, params) req.send_request() end |
#stop_code_interpreter_session(params = {}) ⇒ Types::StopCodeInterpreterSessionResponse
Terminates an active code interpreter session in Amazon Bedrock AgentCore. This operation stops the session, releases associated resources, and makes the session unavailable for further use.
To stop a code interpreter session, you must specify both the code interpreter identifier and the session ID. Once stopped, a session cannot be restarted; you must create a new session using ‘StartCodeInterpreterSession`.
The following operations are related to ‘StopCodeInterpreterSession`:
- StartCodeInterpreterSession][1
- GetCodeInterpreterSession][2
[1]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_StartCodeInterpreterSession.html [2]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_GetCodeInterpreterSession.html
5850 5851 5852 5853 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 5850 def stop_code_interpreter_session(params = {}, = {}) req = build_request(:stop_code_interpreter_session, params) req.send_request() end |
#stop_runtime_session(params = {}) ⇒ Types::StopRuntimeSessionResponse
Stops a session that is running in an running AgentCore Runtime agent.
5899 5900 5901 5902 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 5899 def stop_runtime_session(params = {}, = {}) req = build_request(:stop_runtime_session, params) req.send_request() end |
#update_ab_test(params = {}) ⇒ Types::UpdateABTestResponse
Updates an A/B test’s configuration, including variants, traffic allocation, evaluation settings, or execution status.
5998 5999 6000 6001 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 5998 def update_ab_test(params = {}, = {}) req = build_request(:update_ab_test, params) req.send_request() end |
#update_browser_stream(params = {}) ⇒ Types::UpdateBrowserStreamResponse
Updates a browser stream. To use this operation, you must have permissions to perform the bedrock:UpdateBrowserStream action.
6057 6058 6059 6060 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 6057 def update_browser_stream(params = {}, = {}) req = build_request(:update_browser_stream, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6086 6087 6088 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 6086 def waiter_names [] end |