Class: Aws::BedrockAgentCore::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::BedrockAgentCore::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-bedrockagentcore/client.rb
Overview
An API client for BedrockAgentCore. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::BedrockAgentCore::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_create_memory_records(params = {}) ⇒ Types::BatchCreateMemoryRecordsOutput
Creates multiple memory records in a single batch operation for the specified memory with custom content.
-
#batch_delete_memory_records(params = {}) ⇒ Types::BatchDeleteMemoryRecordsOutput
Deletes multiple memory records in a single batch operation from the specified memory.
-
#batch_update_memory_records(params = {}) ⇒ Types::BatchUpdateMemoryRecordsOutput
Updates multiple memory records with custom content in a single batch operation within the specified memory.
-
#complete_resource_token_auth(params = {}) ⇒ Struct
Confirms the user authentication session for obtaining OAuth2.0 tokens for a resource.
-
#create_ab_test(params = {}) ⇒ Types::CreateABTestResponse
Creates an A/B test for comparing agent configurations.
-
#create_event(params = {}) ⇒ Types::CreateEventOutput
Creates an event in an AgentCore Memory resource.
-
#create_payment_instrument(params = {}) ⇒ Types::CreatePaymentInstrumentResponse
Create a new payment instrument for a connector.
-
#create_payment_session(params = {}) ⇒ Types::CreatePaymentSessionResponse
Create a new payment manager session.
-
#delete_ab_test(params = {}) ⇒ Types::DeleteABTestResponse
Deletes an A/B test and its associated gateway rules.
-
#delete_batch_evaluation(params = {}) ⇒ Types::DeleteBatchEvaluationResponse
Deletes a batch evaluation and its associated results.
-
#delete_event(params = {}) ⇒ Types::DeleteEventOutput
Deletes an event from an AgentCore Memory resource.
-
#delete_memory_record(params = {}) ⇒ Types::DeleteMemoryRecordOutput
Deletes a memory record from an AgentCore Memory resource.
-
#delete_payment_instrument(params = {}) ⇒ Types::DeletePaymentInstrumentResponse
Delete a payment instrument.
-
#delete_payment_session(params = {}) ⇒ Types::DeletePaymentSessionResponse
Delete a payment manager session.
-
#delete_recommendation(params = {}) ⇒ Types::DeleteRecommendationResponse
Deletes a recommendation and its associated results.
-
#evaluate(params = {}) ⇒ Types::EvaluateResponse
Performs on-demand evaluation of agent traces using a specified evaluator.
-
#get_ab_test(params = {}) ⇒ Types::GetABTestResponse
Retrieves detailed information about an A/B test, including its configuration, status, and statistical results.
-
#get_agent_card(params = {}) ⇒ Types::GetAgentCardResponse
Retrieves the A2A agent card associated with an AgentCore Runtime agent.
-
#get_batch_evaluation(params = {}) ⇒ Types::GetBatchEvaluationResponse
Retrieves detailed information about a batch evaluation, including its status, configuration, results, and any error details.
-
#get_browser_session(params = {}) ⇒ Types::GetBrowserSessionResponse
Retrieves detailed information about a specific browser session in Amazon Bedrock AgentCore.
-
#get_code_interpreter_session(params = {}) ⇒ Types::GetCodeInterpreterSessionResponse
Retrieves detailed information about a specific code interpreter session in Amazon Bedrock AgentCore.
-
#get_event(params = {}) ⇒ Types::GetEventOutput
Retrieves information about a specific event in an AgentCore Memory resource.
-
#get_memory_record(params = {}) ⇒ Types::GetMemoryRecordOutput
Retrieves a specific memory record from an AgentCore Memory resource.
-
#get_payment_instrument(params = {}) ⇒ Types::GetPaymentInstrumentResponse
Get a payment instrument by ID.
-
#get_payment_instrument_balance(params = {}) ⇒ Types::GetPaymentInstrumentBalanceResponse
Get the balance of a payment instrument.
-
#get_payment_session(params = {}) ⇒ Types::GetPaymentSessionResponse
Get a payment session.
-
#get_recommendation(params = {}) ⇒ Types::GetRecommendationResponse
Retrieves detailed information about a recommendation, including its configuration, status, and results.
-
#get_resource_api_key(params = {}) ⇒ Types::GetResourceApiKeyResponse
Retrieves the API key associated with an API key credential provider.
-
#get_resource_oauth_2_token(params = {}) ⇒ Types::GetResourceOauth2TokenResponse
Returns the OAuth 2.0 token of the provided resource.
-
#get_resource_payment_token(params = {}) ⇒ Types::GetResourcePaymentTokenResponse
Generates authentication tokens for payment providers that use vendor-specific authentication mechanisms.
-
#get_workload_access_token(params = {}) ⇒ Types::GetWorkloadAccessTokenResponse
Obtains a workload access token for agentic workloads not acting on behalf of a user.
-
#get_workload_access_token_for_jwt(params = {}) ⇒ Types::GetWorkloadAccessTokenForJWTResponse
Obtains a workload access token for agentic workloads acting on behalf of a user, using a JWT token.
-
#get_workload_access_token_for_user_id(params = {}) ⇒ Types::GetWorkloadAccessTokenForUserIdResponse
Obtains a workload access token for agentic workloads acting on behalf of a user, using the user’s ID.
-
#invoke_agent_runtime(params = {}) ⇒ Types::InvokeAgentRuntimeResponse
Sends a request to an agent or tool hosted in an Amazon Bedrock AgentCore Runtime and receives responses in real-time.
-
#invoke_agent_runtime_command(params = {}) ⇒ Types::InvokeAgentRuntimeCommandResponse
Executes a command in a runtime session container and streams the output back to the caller.
-
#invoke_browser(params = {}) ⇒ Types::InvokeBrowserResponse
Invokes an operating system-level action on a browser session in Amazon Bedrock AgentCore.
-
#invoke_code_interpreter(params = {}) ⇒ Types::InvokeCodeInterpreterResponse
Executes code within an active code interpreter session in Amazon Bedrock AgentCore.
-
#invoke_harness(params = {}) ⇒ Types::InvokeHarnessResponse
Operation to invoke a Harness.
-
#list_ab_tests(params = {}) ⇒ Types::ListABTestsResponse
Lists all A/B tests in the account.
-
#list_actors(params = {}) ⇒ Types::ListActorsOutput
Lists all actors in an AgentCore Memory resource.
-
#list_batch_evaluations(params = {}) ⇒ Types::ListBatchEvaluationsResponse
Lists all batch evaluations in the account, providing summary information about each evaluation’s status and configuration.
-
#list_browser_sessions(params = {}) ⇒ Types::ListBrowserSessionsResponse
Retrieves a list of browser sessions in Amazon Bedrock AgentCore that match the specified criteria.
-
#list_code_interpreter_sessions(params = {}) ⇒ Types::ListCodeInterpreterSessionsResponse
Retrieves a list of code interpreter sessions in Amazon Bedrock AgentCore that match the specified criteria.
-
#list_events(params = {}) ⇒ Types::ListEventsOutput
Lists events in an AgentCore Memory resource based on specified criteria.
-
#list_memory_extraction_jobs(params = {}) ⇒ Types::ListMemoryExtractionJobsOutput
Lists all long-term memory extraction jobs that are eligible to be started with optional filtering.
-
#list_memory_records(params = {}) ⇒ Types::ListMemoryRecordsOutput
Lists memory records in an AgentCore Memory resource based on specified criteria.
-
#list_payment_instruments(params = {}) ⇒ Types::ListPaymentInstrumentsResponse
List payment instruments for a manager.
-
#list_payment_sessions(params = {}) ⇒ Types::ListPaymentSessionsResponse
List payment manager sessions.
-
#list_recommendations(params = {}) ⇒ Types::ListRecommendationsResponse
Lists all recommendations in the account, with optional filtering by status.
-
#list_sessions(params = {}) ⇒ Types::ListSessionsOutput
Lists sessions in an AgentCore Memory resource based on specified criteria.
-
#process_payment(params = {}) ⇒ Types::ProcessPaymentResponse
Process a payment transaction.
-
#retrieve_memory_records(params = {}) ⇒ Types::RetrieveMemoryRecordsOutput
Searches for and retrieves memory records from an AgentCore Memory resource based on specified search criteria.
-
#save_browser_session_profile(params = {}) ⇒ Types::SaveBrowserSessionProfileResponse
Saves the current state of a browser session as a reusable profile in Amazon Bedrock AgentCore.
-
#search_registry_records(params = {}) ⇒ Types::SearchRegistryRecordsResponse
Searches for registry records using semantic, lexical, or hybrid queries.
-
#start_batch_evaluation(params = {}) ⇒ Types::StartBatchEvaluationResponse
Starts a batch evaluation job that evaluates agent performance across multiple sessions.
-
#start_browser_session(params = {}) ⇒ Types::StartBrowserSessionResponse
Creates and initializes a browser session in Amazon Bedrock AgentCore.
-
#start_code_interpreter_session(params = {}) ⇒ Types::StartCodeInterpreterSessionResponse
Creates and initializes a code interpreter session in Amazon Bedrock AgentCore.
-
#start_memory_extraction_job(params = {}) ⇒ Types::StartMemoryExtractionJobOutput
Starts a memory extraction job that processes events that failed extraction previously in an AgentCore Memory resource and produces structured memory records.
-
#start_recommendation(params = {}) ⇒ Types::StartRecommendationResponse
Starts a recommendation job that analyzes agent traces and generates optimization suggestions for system prompts or tool descriptions to improve agent performance.
-
#stop_batch_evaluation(params = {}) ⇒ Types::StopBatchEvaluationResponse
Stops a running batch evaluation.
-
#stop_browser_session(params = {}) ⇒ Types::StopBrowserSessionResponse
Terminates an active browser session in Amazon Bedrock AgentCore.
-
#stop_code_interpreter_session(params = {}) ⇒ Types::StopCodeInterpreterSessionResponse
Terminates an active code interpreter session in Amazon Bedrock AgentCore.
-
#stop_runtime_session(params = {}) ⇒ Types::StopRuntimeSessionResponse
Stops a session that is running in an running AgentCore Runtime agent.
-
#update_ab_test(params = {}) ⇒ Types::UpdateABTestResponse
Updates an A/B test’s configuration, including variants, traffic allocation, evaluation settings, or execution status.
-
#update_browser_stream(params = {}) ⇒ Types::UpdateBrowserStreamResponse
Updates a browser stream.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
484 485 486 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 484 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6130 6131 6132 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 6130 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6133 6134 6135 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 6133 def errors_module Errors end |
Instance Method Details
#batch_create_memory_records(params = {}) ⇒ Types::BatchCreateMemoryRecordsOutput
Creates multiple memory records in a single batch operation for the specified memory with custom content.
557 558 559 560 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 557 def batch_create_memory_records(params = {}, = {}) req = build_request(:batch_create_memory_records, params) req.send_request() end |
#batch_delete_memory_records(params = {}) ⇒ Types::BatchDeleteMemoryRecordsOutput
Deletes multiple memory records in a single batch operation from the specified memory.
607 608 609 610 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 607 def batch_delete_memory_records(params = {}, = {}) req = build_request(:batch_delete_memory_records, params) req.send_request() end |
#batch_update_memory_records(params = {}) ⇒ Types::BatchUpdateMemoryRecordsOutput
Updates multiple memory records with custom content in a single batch operation within the specified memory.
671 672 673 674 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 671 def batch_update_memory_records(params = {}, = {}) req = build_request(:batch_update_memory_records, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6103 6104 6105 6106 6107 6108 6109 6110 6111 6112 6113 6114 6115 6116 6117 6118 6119 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 6103 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::BedrockAgentCore') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-bedrockagentcore' context[:gem_version] = '1.32.0' Seahorse::Client::Request.new(handlers, context) end |
#complete_resource_token_auth(params = {}) ⇒ Struct
Confirms the user authentication session for obtaining OAuth2.0 tokens for a resource.
706 707 708 709 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 706 def complete_resource_token_auth(params = {}, = {}) req = build_request(:complete_resource_token_auth, params) req.send_request() end |
#create_ab_test(params = {}) ⇒ Types::CreateABTestResponse
Creates an A/B test for comparing agent configurations. A/B tests split traffic between a control variant and a treatment variant through a gateway, then evaluate performance using online evaluation configurations to determine which variant performs better.
816 817 818 819 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 816 def create_ab_test(params = {}, = {}) req = build_request(:create_ab_test, params) req.send_request() end |
#create_event(params = {}) ⇒ Types::CreateEventOutput
Creates an event in an AgentCore Memory resource. Events represent interactions or activities that occur within a session and are associated with specific actors.
To use this operation, you must have the ‘bedrock-agentcore:CreateEvent` permission.
This operation is subject to request rate limiting.
920 921 922 923 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 920 def create_event(params = {}, = {}) req = build_request(:create_event, params) req.send_request() end |
#create_payment_instrument(params = {}) ⇒ Types::CreatePaymentInstrumentResponse
Create a new payment instrument for a connector
1062 1063 1064 1065 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 1062 def create_payment_instrument(params = {}, = {}) req = build_request(:create_payment_instrument, params) req.send_request() end |
#create_payment_session(params = {}) ⇒ Types::CreatePaymentSessionResponse
Create a new payment manager session
1129 1130 1131 1132 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 1129 def create_payment_session(params = {}, = {}) req = build_request(:create_payment_session, params) req.send_request() end |
#delete_ab_test(params = {}) ⇒ Types::DeleteABTestResponse
Deletes an A/B test and its associated gateway rules.
1161 1162 1163 1164 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 1161 def delete_ab_test(params = {}, = {}) req = build_request(:delete_ab_test, params) req.send_request() end |
#delete_batch_evaluation(params = {}) ⇒ Types::DeleteBatchEvaluationResponse
Deletes a batch evaluation and its associated results.
1193 1194 1195 1196 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 1193 def delete_batch_evaluation(params = {}, = {}) req = build_request(:delete_batch_evaluation, params) req.send_request() end |
#delete_event(params = {}) ⇒ Types::DeleteEventOutput
Deletes an event from an AgentCore Memory resource. When you delete an event, it is permanently removed.
To use this operation, you must have the ‘bedrock-agentcore:DeleteEvent` permission.
1238 1239 1240 1241 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 1238 def delete_event(params = {}, = {}) req = build_request(:delete_event, params) req.send_request() end |
#delete_memory_record(params = {}) ⇒ Types::DeleteMemoryRecordOutput
Deletes a memory record from an AgentCore Memory resource. When you delete a memory record, it is permanently removed.
To use this operation, you must have the ‘bedrock-agentcore:DeleteMemoryRecord` permission.
1275 1276 1277 1278 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 1275 def delete_memory_record(params = {}, = {}) req = build_request(:delete_memory_record, params) req.send_request() end |
#delete_payment_instrument(params = {}) ⇒ Types::DeletePaymentInstrumentResponse
Delete a payment instrument
Marks a payment instrument as deleted by updating its status to DELETED. This is a soft delete operation that preserves the record in the database for audit and compliance purposes. The record remains queryable for audit purposes but is excluded from normal list and get operations.
Deleting an already-deleted or non-existent instrument returns ResourceNotFoundException (404).
Authorization: The caller must own the instrument (accountId, userId, and paymentManagerId must match). If authorization fails, a 403 Forbidden error is returned.
Timestamp Management: The updatedAt timestamp is set to the current time, while createdAt is preserved. The version field is incremented for optimistic locking.
Errors:
-
ResourceNotFoundException: The instrument does not exist or is already deleted
-
AccessDeniedException: The caller is not authorized to delete this instrument
-
ValidationException: Required fields are missing or invalid
-
InternalServerException: An unexpected server error occurred
1344 1345 1346 1347 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 1344 def delete_payment_instrument(params = {}, = {}) req = build_request(:delete_payment_instrument, params) req.send_request() end |
#delete_payment_session(params = {}) ⇒ Types::DeletePaymentSessionResponse
Delete a payment manager session
Permanently removes a payment session record from the database. This is a hard delete operation that removes the session completely.
Deleting a non-existent or already-deleted session returns ResourceNotFoundException (404).
Authorization: The caller must own the session (accountId, userId, and paymentManagerId must match). If authorization fails, a 403 Forbidden error is returned.
Errors:
-
ResourceNotFoundException: The session does not exist or has already been deleted
-
AccessDeniedException: The caller is not authorized to delete this session
-
ValidationException: Required fields are missing or invalid
-
InternalServerException: An unexpected server error occurred
1400 1401 1402 1403 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 1400 def delete_payment_session(params = {}, = {}) req = build_request(:delete_payment_session, params) req.send_request() end |
#delete_recommendation(params = {}) ⇒ Types::DeleteRecommendationResponse
Deletes a recommendation and its associated results.
1430 1431 1432 1433 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 1430 def delete_recommendation(params = {}, = {}) req = build_request(:delete_recommendation, params) req.send_request() end |
#evaluate(params = {}) ⇒ Types::EvaluateResponse
Performs on-demand evaluation of agent traces using a specified evaluator. This synchronous API accepts traces in OpenTelemetry format and returns immediate scoring results with detailed explanations.
1531 1532 1533 1534 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 1531 def evaluate(params = {}, = {}) req = build_request(:evaluate, params) req.send_request() end |
#get_ab_test(params = {}) ⇒ Types::GetABTestResponse
Retrieves detailed information about an A/B test, including its configuration, status, and statistical results.
1621 1622 1623 1624 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 1621 def get_ab_test(params = {}, = {}) req = build_request(:get_ab_test, params) req.send_request() end |
#get_agent_card(params = {}) ⇒ Types::GetAgentCardResponse
Retrieves the A2A agent card associated with an AgentCore Runtime agent.
1666 1667 1668 1669 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 1666 def get_agent_card(params = {}, = {}) req = build_request(:get_agent_card, params) req.send_request() end |
#get_batch_evaluation(params = {}) ⇒ Types::GetBatchEvaluationResponse
Retrieves detailed information about a batch evaluation, including its status, configuration, results, and any error details.
1736 1737 1738 1739 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 1736 def get_batch_evaluation(params = {}, = {}) req = build_request(:get_batch_evaluation, params) req.send_request() end |
#get_browser_session(params = {}) ⇒ Types::GetBrowserSessionResponse
Retrieves detailed information about a specific browser session in Amazon Bedrock AgentCore. This operation returns the session’s configuration, current status, associated streams, and metadata.
To get a browser session, you must specify both the browser identifier and the session ID. The response includes information about the session’s viewport configuration, timeout settings, and stream endpoints.
The following operations are related to ‘GetBrowserSession`:
- StartBrowserSession][1
- ListBrowserSessions][2
- StopBrowserSession][3
[1]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_StartBrowserSession.html [2]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_ListBrowserSessions.html [3]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_StopBrowserSession.html
1835 1836 1837 1838 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 1835 def get_browser_session(params = {}, = {}) req = build_request(:get_browser_session, params) req.send_request() end |
#get_code_interpreter_session(params = {}) ⇒ Types::GetCodeInterpreterSessionResponse
Retrieves detailed information about a specific code interpreter session in Amazon Bedrock AgentCore. This operation returns the session’s configuration, current status, and metadata.
To get a code interpreter session, you must specify both the code interpreter identifier and the session ID. The response includes information about the session’s timeout settings and current status.
The following operations are related to ‘GetCodeInterpreterSession`:
- StartCodeInterpreterSession][1
- ListCodeInterpreterSessions][2
- StopCodeInterpreterSession][3
[1]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_StartCodeInterpreterSession.html [2]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_ListCodeInterpreterSessions.html [3]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_StopCodeInterpreterSession.html
1901 1902 1903 1904 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 1901 def get_code_interpreter_session(params = {}, = {}) req = build_request(:get_code_interpreter_session, params) req.send_request() end |
#get_event(params = {}) ⇒ Types::GetEventOutput
Retrieves information about a specific event in an AgentCore Memory resource.
To use this operation, you must have the ‘bedrock-agentcore:GetEvent` permission.
1956 1957 1958 1959 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 1956 def get_event(params = {}, = {}) req = build_request(:get_event, params) req.send_request() end |
#get_memory_record(params = {}) ⇒ Types::GetMemoryRecordOutput
Retrieves a specific memory record from an AgentCore Memory resource.
To use this operation, you must have the ‘bedrock-agentcore:GetMemoryRecord` permission.
2003 2004 2005 2006 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 2003 def get_memory_record(params = {}, = {}) req = build_request(:get_memory_record, params) req.send_request() end |
#get_payment_instrument(params = {}) ⇒ Types::GetPaymentInstrumentResponse
Get a payment instrument by ID
2082 2083 2084 2085 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 2082 def get_payment_instrument(params = {}, = {}) req = build_request(:get_payment_instrument, params) req.send_request() end |
#get_payment_instrument_balance(params = {}) ⇒ Types::GetPaymentInstrumentBalanceResponse
Get the balance of a payment instrument
2143 2144 2145 2146 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 2143 def get_payment_instrument_balance(params = {}, = {}) req = build_request(:get_payment_instrument_balance, params) req.send_request() end |
#get_payment_session(params = {}) ⇒ Types::GetPaymentSessionResponse
Get a payment session
2193 2194 2195 2196 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 2193 def get_payment_session(params = {}, = {}) req = build_request(:get_payment_session, params) req.send_request() end |
#get_recommendation(params = {}) ⇒ Types::GetRecommendationResponse
Retrieves detailed information about a recommendation, including its configuration, status, and results.
2290 2291 2292 2293 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 2290 def get_recommendation(params = {}, = {}) req = build_request(:get_recommendation, params) req.send_request() end |
#get_resource_api_key(params = {}) ⇒ Types::GetResourceApiKeyResponse
Retrieves the API key associated with an API key credential provider.
2324 2325 2326 2327 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 2324 def get_resource_api_key(params = {}, = {}) req = build_request(:get_resource_api_key, params) req.send_request() end |
#get_resource_oauth_2_token(params = {}) ⇒ Types::GetResourceOauth2TokenResponse
Returns the OAuth 2.0 token of the provided resource.
2415 2416 2417 2418 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 2415 def get_resource_oauth_2_token(params = {}, = {}) req = build_request(:get_resource_oauth_2_token, params) req.send_request() end |
#get_resource_payment_token(params = {}) ⇒ Types::GetResourcePaymentTokenResponse
Generates authentication tokens for payment providers that use vendor-specific authentication mechanisms.
2473 2474 2475 2476 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 2473 def get_resource_payment_token(params = {}, = {}) req = build_request(:get_resource_payment_token, params) req.send_request() end |
#get_workload_access_token(params = {}) ⇒ Types::GetWorkloadAccessTokenResponse
Obtains a workload access token for agentic workloads not acting on behalf of a user.
2502 2503 2504 2505 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 2502 def get_workload_access_token(params = {}, = {}) req = build_request(:get_workload_access_token, params) req.send_request() end |
#get_workload_access_token_for_jwt(params = {}) ⇒ Types::GetWorkloadAccessTokenForJWTResponse
Obtains a workload access token for agentic workloads acting on behalf of a user, using a JWT token.
2535 2536 2537 2538 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 2535 def get_workload_access_token_for_jwt(params = {}, = {}) req = build_request(:get_workload_access_token_for_jwt, params) req.send_request() end |
#get_workload_access_token_for_user_id(params = {}) ⇒ Types::GetWorkloadAccessTokenForUserIdResponse
Obtains a workload access token for agentic workloads acting on behalf of a user, using the user’s ID.
2569 2570 2571 2572 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 2569 def get_workload_access_token_for_user_id(params = {}, = {}) req = build_request(:get_workload_access_token_for_user_id, params) req.send_request() end |
#invoke_agent_runtime(params = {}) ⇒ Types::InvokeAgentRuntimeResponse
Sends a request to an agent or tool hosted in an Amazon Bedrock AgentCore Runtime and receives responses in real-time.
To invoke an agent, you can specify either the AgentCore Runtime ARN or the agent ID with an account ID, and provide a payload containing your request. When you use the agent ID instead of the full ARN, you don’t need to URL-encode the identifier. You can optionally specify a qualifier to target a specific endpoint of the agent.
This operation supports streaming responses, allowing you to receive partial responses as they become available. We recommend using pagination to ensure that the operation returns quickly and successfully when processing large responses.
For example code, see [Invoke an AgentCore Runtime agent].
If you’re integrating your agent with OAuth, you can’t use the Amazon Web Services SDK to call ‘InvokeAgentRuntime`. Instead, make a HTTPS request to `InvokeAgentRuntime`. For an example, see [Authenticate and authorize with Inbound Auth and Outbound Auth].
To use this operation, you must have the ‘bedrock-agentcore:InvokeAgentRuntime` permission. If you are making a call to `InvokeAgentRuntime` on behalf of a user ID with the `X-Amzn-Bedrock-AgentCore-Runtime-User-Id` header, You require permissions to both actions (`bedrock-agentcore:InvokeAgentRuntime` and `bedrock-agentcore:InvokeAgentRuntimeForUser`).
[1]: docs.aws.amazon.com/bedrock-agentcore/latest/devguide/runtime-invoke-agent.html [2]: docs.aws.amazon.com/bedrock-agentcore/latest/devguide/runtime-oauth.html
2715 2716 2717 2718 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 2715 def invoke_agent_runtime(params = {}, = {}, &block) req = build_request(:invoke_agent_runtime, params) req.send_request(, &block) end |
#invoke_agent_runtime_command(params = {}) ⇒ Types::InvokeAgentRuntimeCommandResponse
Executes a command in a runtime session container and streams the output back to the caller. This operation allows you to run shell commands within the agent runtime environment and receive real-time streaming responses including standard output and standard error.
To invoke a command, you must specify the agent runtime ARN and a runtime session ID. The command execution supports streaming responses, allowing you to receive output as it becomes available through ‘contentStart`, `contentDelta`, and `contentStop` events.
To use this operation, you must have the ‘bedrock-agentcore:InvokeAgentRuntimeCommand` permission.
3012 3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 3012 def invoke_agent_runtime_command(params = {}, = {}, &block) params = params.dup event_stream_handler = case handler = params.delete(:event_stream_handler) when EventStreams::InvokeAgentRuntimeCommandStreamOutput then handler when Proc then EventStreams::InvokeAgentRuntimeCommandStreamOutput.new.tap(&handler) when nil then EventStreams::InvokeAgentRuntimeCommandStreamOutput.new else msg = "expected :event_stream_handler to be a block or "\ "instance of Aws::BedrockAgentCore::EventStreams::InvokeAgentRuntimeCommandStreamOutput"\ ", got `#{handler.inspect}` instead" raise ArgumentError, msg end yield(event_stream_handler) if block_given? req = build_request(:invoke_agent_runtime_command, params) req.context[:event_stream_handler] = event_stream_handler req.handlers.add(Aws::Binary::DecodeHandler, priority: 95) req.send_request(, &block) end |
#invoke_browser(params = {}) ⇒ Types::InvokeBrowserResponse
Invokes an operating system-level action on a browser session in Amazon Bedrock AgentCore. This operation provides direct OS-level control over browser sessions, enabling mouse actions, keyboard input, and screenshots that the WebSocket-based Chrome DevTools Protocol (CDP) cannot handle — such as interacting with print dialogs, context menus, and JavaScript alerts.
You send a request with exactly one action in the ‘BrowserAction` union, and receive a corresponding result in the `BrowserActionResult` union.
The following operations are related to ‘InvokeBrowser`:
- StartBrowserSession][1
- GetBrowserSession][2
- StopBrowserSession][3
[1]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_StartBrowserSession.html [2]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_GetBrowserSession.html [3]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_StopBrowserSession.html
3149 3150 3151 3152 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 3149 def invoke_browser(params = {}, = {}) req = build_request(:invoke_browser, params) req.send_request() end |
#invoke_code_interpreter(params = {}) ⇒ Types::InvokeCodeInterpreterResponse
Executes code within an active code interpreter session in Amazon Bedrock AgentCore. This operation processes the provided code, runs it in a secure environment, and returns the execution results including output, errors, and generated visualizations.
To execute code, you must specify the code interpreter identifier, session ID, and the code to run in the arguments parameter. The operation returns a stream containing the execution results, which can include text output, error messages, and data visualizations.
This operation is subject to request rate limiting based on your account’s service quotas.
The following operations are related to ‘InvokeCodeInterpreter`:
- StartCodeInterpreterSession][1
- GetCodeInterpreterSession][2
[1]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_StartCodeInterpreterSession.html [2]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_GetCodeInterpreterSession.html
3448 3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 3466 3467 3468 3469 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 3448 def invoke_code_interpreter(params = {}, = {}, &block) params = params.dup event_stream_handler = case handler = params.delete(:event_stream_handler) when EventStreams::CodeInterpreterStreamOutput then handler when Proc then EventStreams::CodeInterpreterStreamOutput.new.tap(&handler) when nil then EventStreams::CodeInterpreterStreamOutput.new else msg = "expected :event_stream_handler to be a block or "\ "instance of Aws::BedrockAgentCore::EventStreams::CodeInterpreterStreamOutput"\ ", got `#{handler.inspect}` instead" raise ArgumentError, msg end yield(event_stream_handler) if block_given? req = build_request(:invoke_code_interpreter, params) req.context[:event_stream_handler] = event_stream_handler req.handlers.add(Aws::Binary::DecodeHandler, priority: 95) req.send_request(, &block) end |
#invoke_harness(params = {}) ⇒ Types::InvokeHarnessResponse
Operation to invoke a Harness.
3868 3869 3870 3871 3872 3873 3874 3875 3876 3877 3878 3879 3880 3881 3882 3883 3884 3885 3886 3887 3888 3889 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 3868 def invoke_harness(params = {}, = {}, &block) params = params.dup event_stream_handler = case handler = params.delete(:event_stream_handler) when EventStreams::InvokeHarnessStreamOutput then handler when Proc then EventStreams::InvokeHarnessStreamOutput.new.tap(&handler) when nil then EventStreams::InvokeHarnessStreamOutput.new else msg = "expected :event_stream_handler to be a block or "\ "instance of Aws::BedrockAgentCore::EventStreams::InvokeHarnessStreamOutput"\ ", got `#{handler.inspect}` instead" raise ArgumentError, msg end yield(event_stream_handler) if block_given? req = build_request(:invoke_harness, params) req.context[:event_stream_handler] = event_stream_handler req.handlers.add(Aws::Binary::DecodeHandler, priority: 95) req.send_request(, &block) end |
#list_ab_tests(params = {}) ⇒ Types::ListABTestsResponse
Lists all A/B tests in the account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3937 3938 3939 3940 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 3937 def list_ab_tests(params = {}, = {}) req = build_request(:list_ab_tests, params) req.send_request() end |
#list_actors(params = {}) ⇒ Types::ListActorsOutput
Lists all actors in an AgentCore Memory resource. We recommend using pagination to ensure that the operation returns quickly and successfully.
To use this operation, you must have the ‘bedrock-agentcore:ListActors` permission.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3987 3988 3989 3990 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 3987 def list_actors(params = {}, = {}) req = build_request(:list_actors, params) req.send_request() end |
#list_batch_evaluations(params = {}) ⇒ Types::ListBatchEvaluationsResponse
Lists all batch evaluations in the account, providing summary information about each evaluation’s status and configuration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4051 4052 4053 4054 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 4051 def list_batch_evaluations(params = {}, = {}) req = build_request(:list_batch_evaluations, params) req.send_request() end |
#list_browser_sessions(params = {}) ⇒ Types::ListBrowserSessionsResponse
Retrieves a list of browser sessions in Amazon Bedrock AgentCore that match the specified criteria. This operation returns summary information about each session, including identifiers, status, and timestamps.
You can filter the results by browser identifier and session status. The operation supports pagination to handle large result sets efficiently.
We recommend using pagination to ensure that the operation returns quickly and successfully when retrieving large numbers of sessions.
The following operations are related to ‘ListBrowserSessions`:
- StartBrowserSession][1
- GetBrowserSession][2
[1]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_StartBrowserSession.html [2]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_GetBrowserSession.html
4130 4131 4132 4133 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 4130 def list_browser_sessions(params = {}, = {}) req = build_request(:list_browser_sessions, params) req.send_request() end |
#list_code_interpreter_sessions(params = {}) ⇒ Types::ListCodeInterpreterSessionsResponse
Retrieves a list of code interpreter sessions in Amazon Bedrock AgentCore that match the specified criteria. This operation returns summary information about each session, including identifiers, status, and timestamps.
You can filter the results by code interpreter identifier and session status. The operation supports pagination to handle large result sets efficiently.
We recommend using pagination to ensure that the operation returns quickly and successfully when retrieving large numbers of sessions.
The following operations are related to ‘ListCodeInterpreterSessions`:
- StartCodeInterpreterSession][1
- GetCodeInterpreterSession][2
[1]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_StartCodeInterpreterSession.html [2]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_GetCodeInterpreterSession.html
4209 4210 4211 4212 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 4209 def list_code_interpreter_sessions(params = {}, = {}) req = build_request(:list_code_interpreter_sessions, params) req.send_request() end |
#list_events(params = {}) ⇒ Types::ListEventsOutput
Lists events in an AgentCore Memory resource based on specified criteria. We recommend using pagination to ensure that the operation returns quickly and successfully.
To use this operation, you must have the ‘bedrock-agentcore:ListEvents` permission.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4305 4306 4307 4308 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 4305 def list_events(params = {}, = {}) req = build_request(:list_events, params) req.send_request() end |
#list_memory_extraction_jobs(params = {}) ⇒ Types::ListMemoryExtractionJobsOutput
Lists all long-term memory extraction jobs that are eligible to be started with optional filtering.
To use this operation, you must have the ‘bedrock-agentcore:ListMemoryExtractionJobs` permission.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4370 4371 4372 4373 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 4370 def list_memory_extraction_jobs(params = {}, = {}) req = build_request(:list_memory_extraction_jobs, params) req.send_request() end |
#list_memory_records(params = {}) ⇒ Types::ListMemoryRecordsOutput
Lists memory records in an AgentCore Memory resource based on specified criteria. We recommend using pagination to ensure that the operation returns quickly and successfully.
To use this operation, you must have the ‘bedrock-agentcore:ListMemoryRecords` permission.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4467 4468 4469 4470 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 4467 def list_memory_records(params = {}, = {}) req = build_request(:list_memory_records, params) req.send_request() end |
#list_payment_instruments(params = {}) ⇒ Types::ListPaymentInstrumentsResponse
List payment instruments for a manager
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4527 4528 4529 4530 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 4527 def list_payment_instruments(params = {}, = {}) req = build_request(:list_payment_instruments, params) req.send_request() end |
#list_payment_sessions(params = {}) ⇒ Types::ListPaymentSessionsResponse
List payment manager sessions
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4581 4582 4583 4584 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 4581 def list_payment_sessions(params = {}, = {}) req = build_request(:list_payment_sessions, params) req.send_request() end |
#list_recommendations(params = {}) ⇒ Types::ListRecommendationsResponse
Lists all recommendations in the account, with optional filtering by status.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4637 4638 4639 4640 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 4637 def list_recommendations(params = {}, = {}) req = build_request(:list_recommendations, params) req.send_request() end |
#list_sessions(params = {}) ⇒ Types::ListSessionsOutput
Lists sessions in an AgentCore Memory resource based on specified criteria. We recommend using pagination to ensure that the operation returns quickly and successfully.
Empty sessions are automatically deleted after one day.
To use this operation, you must have the ‘bedrock-agentcore:ListSessions` permission.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4701 4702 4703 4704 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 4701 def list_sessions(params = {}, = {}) req = build_request(:list_sessions, params) req.send_request() end |
#process_payment(params = {}) ⇒ Types::ProcessPaymentResponse
Process a payment transaction
4782 4783 4784 4785 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 4782 def process_payment(params = {}, = {}) req = build_request(:process_payment, params) req.send_request() end |
#retrieve_memory_records(params = {}) ⇒ Types::RetrieveMemoryRecordsOutput
Searches for and retrieves memory records from an AgentCore Memory resource based on specified search criteria. We recommend using pagination to ensure that the operation returns quickly and successfully.
To use this operation, you must have the ‘bedrock-agentcore:RetrieveMemoryRecords` permission.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4881 4882 4883 4884 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 4881 def retrieve_memory_records(params = {}, = {}) req = build_request(:retrieve_memory_records, params) req.send_request() end |
#save_browser_session_profile(params = {}) ⇒ Types::SaveBrowserSessionProfileResponse
Saves the current state of a browser session as a reusable profile in Amazon Bedrock AgentCore. A browser profile captures persistent browser data such as cookies and local storage from an active session, enabling you to reuse this data in future browser sessions.
To save a browser session profile, you must specify the profile identifier, browser identifier, and session ID. The session must be active when saving the profile. Once saved, the profile can be used with the ‘StartBrowserSession` operation to initialize new sessions with the stored browser state.
Browser profiles are useful for scenarios that require persistent authentication, maintaining user preferences across sessions, or continuing tasks that depend on previously stored browser data.
The following operations are related to ‘SaveBrowserSessionProfile`:
- StartBrowserSession][1
- GetBrowserSession][2
[1]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_StartBrowserSession.html [2]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_GetBrowserSession.html
4971 4972 4973 4974 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 4971 def save_browser_session_profile(params = {}, = {}) req = build_request(:save_browser_session_profile, params) req.send_request() end |
#search_registry_records(params = {}) ⇒ Types::SearchRegistryRecordsResponse
Searches for registry records using semantic, lexical, or hybrid queries. Returns metadata for matching records ordered by relevance within the specified registry.
5049 5050 5051 5052 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 5049 def search_registry_records(params = {}, = {}) req = build_request(:search_registry_records, params) req.send_request() end |
#start_batch_evaluation(params = {}) ⇒ Types::StartBatchEvaluationResponse
Starts a batch evaluation job that evaluates agent performance across multiple sessions. Batch evaluations pull agent traces from CloudWatch Logs or an existing online evaluation configuration and run specified evaluators and insights against them.
5174 5175 5176 5177 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 5174 def start_batch_evaluation(params = {}, = {}) req = build_request(:start_batch_evaluation, params) req.send_request() end |
#start_browser_session(params = {}) ⇒ Types::StartBrowserSessionResponse
Creates and initializes a browser session in Amazon Bedrock AgentCore. The session enables agents to navigate and interact with web content, extract information from websites, and perform web-based tasks as part of their response generation.
To create a session, you must specify a browser identifier and a name. You can also configure the viewport dimensions to control the visible area of web content. The session remains active until it times out or you explicitly stop it using the ‘StopBrowserSession` operation.
The following operations are related to ‘StartBrowserSession`:
- GetBrowserSession][1
- UpdateBrowserStream][2
- SaveBrowserSessionProfile][3
- StopBrowserSession][4
- InvokeBrowser][5
[1]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_GetBrowserSession.html [2]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_UpdateBrowserStream.html [3]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_SaveBrowserSessionProfile.html [4]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_StopBrowserSession.html [5]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_InvokeBrowser.html
5359 5360 5361 5362 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 5359 def start_browser_session(params = {}, = {}) req = build_request(:start_browser_session, params) req.send_request() end |
#start_code_interpreter_session(params = {}) ⇒ Types::StartCodeInterpreterSessionResponse
Creates and initializes a code interpreter session in Amazon Bedrock AgentCore. The session enables agents to execute code as part of their response generation, supporting programming languages such as Python for data analysis, visualization, and computation tasks.
To create a session, you must specify a code interpreter identifier and a name. The session remains active until it times out or you explicitly stop it using the ‘StopCodeInterpreterSession` operation.
The following operations are related to ‘StartCodeInterpreterSession`:
- InvokeCodeInterpreter][1
- GetCodeInterpreterSession][2
- StopCodeInterpreterSession][3
[1]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_InvokeCodeInterpreter.html [2]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_GetCodeInterpreterSession.html [3]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_StopCodeInterpreterSession.html
5457 5458 5459 5460 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 5457 def start_code_interpreter_session(params = {}, = {}) req = build_request(:start_code_interpreter_session, params) req.send_request() end |
#start_memory_extraction_job(params = {}) ⇒ Types::StartMemoryExtractionJobOutput
Starts a memory extraction job that processes events that failed extraction previously in an AgentCore Memory resource and produces structured memory records. When earlier extraction attempts have left events unprocessed, this job will pick up and extract those as well.
To use this operation, you must have the ‘bedrock-agentcore:StartMemoryExtractionJob` permission.
5506 5507 5508 5509 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 5506 def start_memory_extraction_job(params = {}, = {}) req = build_request(:start_memory_extraction_job, params) req.send_request() end |
#start_recommendation(params = {}) ⇒ Types::StartRecommendationResponse
Starts a recommendation job that analyzes agent traces and generates optimization suggestions for system prompts or tool descriptions to improve agent performance.
5708 5709 5710 5711 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 5708 def start_recommendation(params = {}, = {}) req = build_request(:start_recommendation, params) req.send_request() end |
#stop_batch_evaluation(params = {}) ⇒ Types::StopBatchEvaluationResponse
Stops a running batch evaluation. Sessions that have already been evaluated retain their results.
5743 5744 5745 5746 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 5743 def stop_batch_evaluation(params = {}, = {}) req = build_request(:stop_batch_evaluation, params) req.send_request() end |
#stop_browser_session(params = {}) ⇒ Types::StopBrowserSessionResponse
Terminates an active browser session in Amazon Bedrock AgentCore. This operation stops the session, releases associated resources, and makes the session unavailable for further use.
To stop a browser session, you must specify both the browser identifier and the session ID. Once stopped, a session cannot be restarted; you must create a new session using ‘StartBrowserSession`.
The following operations are related to ‘StopBrowserSession`:
- StartBrowserSession][1
- GetBrowserSession][2
[1]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_StartBrowserSession.html [2]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_GetBrowserSession.html
5814 5815 5816 5817 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 5814 def stop_browser_session(params = {}, = {}) req = build_request(:stop_browser_session, params) req.send_request() end |
#stop_code_interpreter_session(params = {}) ⇒ Types::StopCodeInterpreterSessionResponse
Terminates an active code interpreter session in Amazon Bedrock AgentCore. This operation stops the session, releases associated resources, and makes the session unavailable for further use.
To stop a code interpreter session, you must specify both the code interpreter identifier and the session ID. Once stopped, a session cannot be restarted; you must create a new session using ‘StartCodeInterpreterSession`.
The following operations are related to ‘StopCodeInterpreterSession`:
- StartCodeInterpreterSession][1
- GetCodeInterpreterSession][2
[1]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_StartCodeInterpreterSession.html [2]: docs.aws.amazon.com/bedrock-agentcore/latest/APIReference/API_GetCodeInterpreterSession.html
5887 5888 5889 5890 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 5887 def stop_code_interpreter_session(params = {}, = {}) req = build_request(:stop_code_interpreter_session, params) req.send_request() end |
#stop_runtime_session(params = {}) ⇒ Types::StopRuntimeSessionResponse
Stops a session that is running in an running AgentCore Runtime agent.
5936 5937 5938 5939 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 5936 def stop_runtime_session(params = {}, = {}) req = build_request(:stop_runtime_session, params) req.send_request() end |
#update_ab_test(params = {}) ⇒ Types::UpdateABTestResponse
Updates an A/B test’s configuration, including variants, traffic allocation, evaluation settings, or execution status.
6035 6036 6037 6038 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 6035 def update_ab_test(params = {}, = {}) req = build_request(:update_ab_test, params) req.send_request() end |
#update_browser_stream(params = {}) ⇒ Types::UpdateBrowserStreamResponse
Updates a browser stream. To use this operation, you must have permissions to perform the bedrock:UpdateBrowserStream action.
6094 6095 6096 6097 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 6094 def update_browser_stream(params = {}, = {}) req = build_request(:update_browser_stream, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6123 6124 6125 |
# File 'lib/aws-sdk-bedrockagentcore/client.rb', line 6123 def waiter_names [] end |